@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: cmds.c,v 1.45 2004/01/14 18:46:20 pvmsrc Exp $";
+	"$Id: cmds.c,v 1.48 2009/01/30 21:22:23 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -36,6 +36,21 @@ static char rcsid[] =
  *	PVM console commands.
  *
  * $Log: cmds.c,v $
+ * Revision 1.48  2009/01/30 21:22:23  pvmsrc
+ * Fixed up insecure usage of fopen() for creating/writing/appending files.
+ * 	- replace with open(...O_EXCL...) and fdopen()...
+ * (Spanker=kohl)
+ *
+ * Revision 1.47  2009/01/29 20:57:14  pvmsrc
+ * Replaced use of PVMTMPNAM() and temporary files for auto-diagnostics...
+ * 	- just use popen() instead, no file race security holes...  :-D
+ * (Spanker=kohl)
+ *
+ * Revision 1.46  2006/08/15 15:03:57  pvmsrc
+ * Extended help text for host add commands...
+ * 	- make note of host option tags...
+ * (Spanker=kohl)
+ *
  * Revision 1.45  2004/01/14 18:46:20  pvmsrc
  * Added new AIX5* arches.
  * (Spanker=kohl)
@@ -1159,17 +1174,12 @@ int rsize;
 {
 	FILE *fp;
 
-	char tfile[1024];
 	char tcmd[1024];
 	char tmp[255];
 
 	int ret = 1;
 	int len;
 
-	/* Generate Temporary File for Test Output */
-
-	(void)PVMTMPNAMFUN(tfile);
-
 	/* Dump Test Label */
 
 	printf( "%s Host \"%s\"...\n", label, hp->hd_name );
@@ -1187,19 +1197,13 @@ int rsize;
 	strcat( tcmd, tmp );
 
 #ifndef WIN32
-	sprintf( tmp, "1>%s 2>&1", tfile );
-#else
-	sprintf( tmp, "> %s", tfile );
-#endif
+	sprintf( tmp, "2>&1" );
 	strcat( tcmd, tmp );
-
-	/* Execute Rsh Command */
-
-	system( tcmd );
+#endif
 
 	/* Collect Rsh Command Results */
 
-	fp = fopen( tfile, "r" );
+	fp = popen( tcmd, "r" );
 
 	if ( fp != NULL ) {
 		if ( fgets( result, rsize, fp ) != NULL ) {
@@ -1216,15 +1220,13 @@ int rsize;
 			printf( "Error Parsing Output - Can't Auto-Diagnose.\n" );
 			ret = 0;
 		}
-		fclose( fp );
+		pclose( fp );
 	}
 	else {
 		printf( "Rsh Command Failed - Check Your Execution Path!\n" );
 		ret = 0;
 	}
 
-	unlink( tfile );
-
 	return( ret );
 }
 
@@ -1493,6 +1495,8 @@ char *helptx[] = {
 
 	"add add         Add hosts to virtual machine",
 	"add Syntax:  add hostname ...",
+	"add   or     add 'hostname <option>=<value>...' ...",
+	"add (See man page for 'pvmd3' for valid host (file) options.)",
 
 	"alias alias       Define/list command aliases",
 	"alias Syntax:  alias [name command args ...]",
@@ -2198,6 +2202,7 @@ spawn_cmd(ac, av)
 	void status_msg();
 	void event_dump_hdr();
 	void output_dump_hdr();
+	int fd;
 
 	while (av[1][0] == '-') {
 		if (ac < 3) {
@@ -2296,7 +2301,19 @@ spawn_cmd(ac, av)
 			printf("[%d]\n", nextjob - joboffset);
 			nextjob++;
 			if (ofn) {
-				jp->j_ff = fopen(ofn, (app ? "a" : "w"));
+				if ( app ) {
+					fd = open( ofn,
+						O_RDWR|O_APPEND|O_CREAT|O_EXCL|O_TRUNC, 0600 );
+				}
+				else {
+					fd = open( ofn, O_RDWR|O_CREAT|O_EXCL|O_TRUNC, 0600 );
+				}
+				if (fd < 0) {
+					perror(ofn);
+					job_free(jp);
+					return 1;
+				}
+				jp->j_ff = fdopen( fd, (app ? "a" : "w") );
 				if (!jp->j_ff) {
 					perror(ofn);
 					job_free(jp);
