@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: cons.c,v 1.31 2001/02/07 23:10:09 pvmsrc Exp $";
+	"$Id: cons.c,v 1.32 2007/04/19 23:14:46 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -37,6 +37,10 @@ static char rcsid[] =
  *	machine and other tasks.
  *
  * $Log: cons.c,v $
+ * Revision 1.32  2007/04/19 23:14:46  pvmsrc
+ * Added cast of completion_matches() to char ** to eliminate gcc warning.
+ * (Spanker=kohl)
+ *
  * Revision 1.31  2001/02/07 23:10:09  pvmsrc
  * CYGWIN Changes.
  * (Spanker=kohl)
@@ -788,7 +792,7 @@ int end;
 			last_line = (char *) NULL;
 		}
 
-		matches = completion_matches( text, command_generator );
+		matches = (char **) completion_matches( text, command_generator );
 
 	}
 
@@ -797,7 +801,7 @@ int end;
 
 		if ( !last_line || strcmp( last_line, rl_line_buffer ) ) {
 
-			matches = completion_matches( text,
+			matches = (char **) completion_matches( text,
 				command_help_generator );
 
 			if ( last_line ) free( last_line );
