@@ -1,12 +1,15 @@
 
+/* $Id: myalloc.h,v 1.5 1999/07/08 18:59:42 kohl Exp $ */
+
 /*
- *         PVM version 3.3:  Parallel Virtual Machine System
+ *         PVM version 3.4:  Parallel Virtual Machine System
  *               University of Tennessee, Knoxville TN.
  *           Oak Ridge National Laboratory, Oak Ridge TN.
  *                   Emory University, Atlanta GA.
- *      Authors:  A. L. Beguelin, J. J. Dongarra, G. A. Geist,
- *    W. C. Jiang, R. J. Manchek, B. K. Moore, and V. S. Sunderam
- *                   (C) 1992 All Rights Reserved
+ *      Authors:  J. J. Dongarra, G. E. Fagg, M. Fischer
+ *          G. A. Geist, J. A. Kohl, R. J. Manchek, P. Mucci,
+ *         P. M. Papadopoulos, S. L. Scott, and V. S. Sunderam
+ *                   (C) 1997 All Rights Reserved
  *
  *                              NOTICE
  *
@@ -31,7 +34,24 @@
  *
  *	Malloc defines.
  *
-$Log: myalloc.h,v $
+ * $Log: myalloc.h,v $
+ * Revision 1.5  1999/07/08 18:59:42  kohl
+ * Fixed "Log" keyword placement.
+ * 	- indent with " * " for new CVS.
+ *
+ * Revision 1.4  1997/07/09  13:21:10  pvmsrc
+ * Fixed Author Header.
+ *
+ * Revision 1.3  1997/01/28  19:13:24  pvmsrc
+ * New Copyright Notice & Authors.
+ *
+ * Revision 1.2  1996/09/26  21:13:45  pvmsrc
+ * Spanked the stupid CVS "Id" strings.
+ * 	- comments for headers, not rcsid's stupid...  :-Q
+ *
+ * Revision 1.1  1996/09/23  20:25:43  pvmsrc
+ * Initial revision
+ *
  * Revision 1.3  1994/11/07  20:53:43  manchek
  * include stdlib if available
  *
