@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: mbox.c,v 1.11 2001/06/27 23:20:51 pvmsrc Exp $";
+	"$Id: mbox.c,v 1.12 2009/01/23 01:12:52 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -182,7 +182,14 @@ static char rcsid[] =
 **********************************************************************/
   
 #include <stdio.h>
+#ifdef HASSTDLIB
+#include <stdlib.h>
+#endif
+#ifdef	SYSVSTR
 #include <string.h>
+#else
+#include <strings.h>
+#endif
 #include "pvm3.h"
 
 #define MBOX_CLASS	"mbox_test"
