@@ -1,5 +1,5 @@
 
-/* $Id: pvm3.h,v 1.52 2004/09/08 19:52:43 pvmsrc Exp $ */
+/* $Id: pvm3.h,v 1.55 2009/01/23 01:27:02 pvmsrc Exp $ */
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -35,6 +35,22 @@
  *	Libpvm3 includes.
  *
  * $Log: pvm3.h,v $
+ * Revision 1.55  2009/01/23 01:27:02  pvmsrc
+ * Upped version to 3.4.6, in preparation for long-awaited release...  :-D
+ * (Spanker=kohl)
+ *
+ * Revision 1.54  2008/12/17 20:53:44  pvmsrc
+ * Hell, just cram the fricking pre-release version in there...
+ * 	- up to 3.4.5+10 now...  :-}
+ * 	(hope this doesn't break anything...! :-)
+ * (Spanker=kohl)
+ *
+ * Revision 1.53  2007/01/04 22:46:20  pvmsrc
+ * Upped PVMTMPNAMLEN again, from 64 to 128.
+ * Also added proto for new pvm_strerror() function.
+ * 	- both submitted by Frank Sonntag <frank.sonntag@metservice.com>
+ * (Spanker=kohl)
+ *
  * Revision 1.52  2004/09/08 19:52:43  pvmsrc
  * Upped to PVM version 3.4.5 (how sequential... :)
  * (Spanker=kohl)
@@ -276,10 +292,10 @@
 *	Release version
 */
 
-#define	PVM_VER				"3.4.5"
+#define	PVM_VER				"3.4.6"
 #define	PVM_MAJOR_VERSION	3
 #define	PVM_MINOR_VERSION	4
-#define PVM_PATCH_VERSION	5
+#define PVM_PATCH_VERSION	6
 
 #ifndef WIN32
 #include	<sys/time.h>
@@ -546,13 +562,13 @@ struct pvmmboxinfo {
 
 #ifdef  NOTMPNAM
 #define PVMTMPNAMFUN(x)		pvmtmpnam(x)
-#define PVMTMPNAMLEN		64
+#define PVMTMPNAMLEN		128
 #else
 #define PVMTMPNAMFUN(x)		tmpnam(x)
 #ifdef L_tmpnam
 #define PVMTMPNAMLEN		L_tmpnam
 #else
-#define PVMTMPNAMLEN		64
+#define PVMTMPNAMLEN		128
 #endif
 #endif
 
@@ -579,6 +595,7 @@ char *pvmtmpnam		__ProtoGlarp__(( char * ));
 #endif
 char *pvmgetrsh		__ProtoGlarp__(( void ));
 char *pvmgettmp		__ProtoGlarp__(( void ));
+char *pvm_strerror	__ProtoGlarp__(( void ));
 
 int pvm_addhosts	__ProtoGlarp__(( char **, int, int * ));
 int pvm_addmhf		__ProtoGlarp__(( int, int, int, int (*) (int) ));
