@@ -1,5 +1,5 @@
 
-/* $Id: Pvmfunpack.c,v 1.2 1998/09/21 20:27:58 pvmsrc Exp $ */
+/* $Id: Pvmfunpack.c,v 1.3 1999/12/10 15:22:14 pvmsrc Exp $ */
 
 #ifdef WIN32
 #include "..\..\src\pvmwin.h"
@@ -35,6 +35,9 @@ __fortran PVMFUNPACK (what, vp, cnt, std, info)
    case INTEGER4:
       *info = pvm_upkint((int*)vp, *cnt, *std);
       break;
+   case INTEGER8:
+      *info = pvm_upklong((long*)vp, *cnt, *std);
+      break;
    case REAL4:
       *info = pvm_upkfloat((float*)vp, *cnt, *std);
       break;
