@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: pvmgsu_aux.c,v 1.9 1997/10/23 14:35:14 pvmsrc Exp $";
+	"$Id: pvmgsu_aux.c,v 1.10 2007/04/19 23:15:33 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -53,6 +53,12 @@ static char rcsid[] =
 #include "pvmgsd.h"
 #include "pvmproto.h"
 
+#ifdef  SYSVSTR
+#include <string.h>
+#else
+#include <strings.h>
+#endif
+
 extern int pvm_errno;
 extern int pvmmytid;
 extern int pvmtoplvl;
