@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: srm.c,v 1.5 2001/02/08 19:54:45 pvmsrc Exp $";
+	"$Id: srm.c,v 1.6 2009/01/23 01:20:37 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -32,7 +32,14 @@ static char rcsid[] =
 
 
 #include <stdio.h>
+#ifdef HASSTDLIB
+#include <stdlib.h>
+#endif
+#ifdef	SYSVSTR
 #include <string.h>
+#else
+#include <strings.h>
+#endif
 #include <sys/time.h>
 #include <signal.h>
 #include "pvm3.h"
