@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: pvmdmimd.c,v 1.4 2002/02/21 23:19:01 pvmsrc Exp $";
+	"$Id: pvmdmimd.c,v 1.6 2009/01/30 21:23:15 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -90,6 +90,16 @@ static char rcsid[] =
  *			tp: task pointer.
  *
 $Log: pvmdmimd.c,v $
+Revision 1.6  2009/01/30 21:23:15  pvmsrc
+Fixed up insecure usage of fopen() for creating/writing/appending files.
+	- replace with open(...O_EXCL...) and fdopen()...
+(Spanker=kohl)
+
+Revision 1.5  2005/08/22 15:13:36  pvmsrc
+Added #include <pvmtev.h> for #include global.h...  :-Q
+	- submitted by Skipper Hartley <charles.l.hartley@bankofamerica.com>
+(Spanker=kohl)
+
 Revision 1.4  2002/02/21 23:19:01  pvmsrc
 Added new (not to be documented!) PVM_MAX_TASKS env var support.
 	- for Mahir Lokvancic <mahir@math.ufl.edu>.
@@ -198,6 +208,7 @@ Cleaned up comments...  mpp_load() args...
 
 #include <pvm3.h>
 #include <pvmproto.h>
+#include <pvmtev.h>
 #include "global.h"
 #include "host.h"
 #include "waitc.h"
@@ -348,6 +359,7 @@ sp2hostfile(first, count)
 {
 	int i;
 	FILE *tmpfp;
+	int fd;
 
 	if (partsize < count) { 
 		sprintf(pvmtxt, "sp2hostfile() need at least %d nodes\n", count+1);
@@ -355,8 +367,13 @@ sp2hostfile(first, count)
 		return (char *)0;
 	}
 	(void)PVMTMPNAMFUN(nodefile);
-	if (!(tmpfp = fopen(nodefile, "w"))) {
-		sprintf(pvmtxt, "sp2hostfile() fopen %s", nodefile);
+	if ((fd = open( nodefile, O_RDWR|O_CREAT|O_EXCL|O_TRUNC, 0600 )) < 0) {
+		sprintf(pvmtxt, "sp2hostfile() open %s", nodefile);
+		pvmlogperror(pvmtxt);
+		return (char *)0;
+	}
+	if (!(tmpfp = fdopen( fd, "w" ))) {
+		sprintf(pvmtxt, "sp2hostfile() fdopen %s", nodefile);
 		pvmlogperror(pvmtxt);
 		return (char *)0;
 	}
