@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: pvmdmimd.c,v 1.1 2004/01/14 17:34:27 pvmsrc Exp $";
+	"$Id: pvmdmimd.c,v 1.2 2009/01/30 21:23:07 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -90,6 +90,11 @@ static char rcsid[] =
  *			tp: task pointer.
  *
 $Log: pvmdmimd.c,v $
+Revision 1.2  2009/01/30 21:23:07  pvmsrc
+Fixed up insecure usage of fopen() for creating/writing/appending files.
+	- replace with open(...O_EXCL...) and fdopen()...
+(Spanker=kohl)
+
 Revision 1.1  2004/01/14 17:34:27  pvmsrc
 New AIX5SP2 arch.
 (Spanker=kohl)
@@ -359,8 +364,13 @@ sp2hostfile(first, count)
 		return (char *)0;
 	}
 	(void)PVMTMPNAMFUN(nodefile);
-	if (!(tmpfp = fopen(nodefile, "w"))) {
-		sprintf(pvmtxt, "sp2hostfile() fopen %s", nodefile);
+	if ((fd = open( nodefile, O_RDWR|O_CREAT|O_EXCL|O_TRUNC, 0600 )) < 0) {
+		sprintf(pvmtxt, "sp2hostfile() open %s", nodefile);
+		pvmlogperror(pvmtxt);
+		return (char *)0;
+	}
+	if (!(tmpfp = fdopen( fd, "w" ))) {
+		sprintf(pvmtxt, "sp2hostfile() fdopen %s", nodefile);
 		pvmlogperror(pvmtxt);
 		return (char *)0;
 	}
