@@ -65,7 +65,7 @@
  *			Send all pending packets to nodes via native send. Node number
  *			and process type are extracted from task ID.
  *
- *		struct task *mpp_find(int pid):
+ *		struct task *mpp_conn(int pid):
  *			Find a task in task table by its Unix pid.
  *
  *		void mpp_free(struct task *tp):
@@ -73,6 +73,15 @@
  *			tp: task pointer.
  *
 $Log: pvmdmimd.c,v $
+Revision 1.4  2009/01/22 23:04:23  pvmsrc
+New version submitted by Paul Springer...
+(Spanker=kohl)
+
+Revision 1.3  2005/08/22 15:13:46  pvmsrc
+Added #include <pvmtev.h> for #include global.h...  :-Q
+	- submitted by Skipper Hartley <charles.l.hartley@bankofamerica.com>
+(Spanker=kohl)
+
 Revision 1.2  2002/02/21 23:19:15  pvmsrc
 Added new (not to be documented!) PVM_MAX_TASKS env var support.
 	- for Mahir Lokvancic <mahir@math.ufl.edu>.
@@ -116,6 +125,7 @@ Architecture-specific Makefile and Pvmd code.
 
 #include <pvm3.h>
 #include <pvmproto.h>
+#include <pvmtev.h>
 #include "global.h"
 #include "host.h"
 #include "waitc.h"
@@ -132,6 +142,7 @@ Architecture-specific Makefile and Pvmd code.
 
 #define BLCOMM		"/usr/bin/rsh"
 #define BLARGC		3
+#define NNAMELENGTH	128
 
 char *getenv();
 
@@ -152,12 +163,17 @@ int tidnmask = TIDNODE;			/* mask for node field of tids */
 
 /* private */
 
-static char rcsid[] = "$Id: pvmdmimd.c,v 1.2 2002/02/21 23:19:15 pvmsrc Exp $";
+static char rcsid[] = "$Id: pvmdmimd.c,v 1.4 2009/01/22 23:04:23 pvmsrc Exp $";
 static struct nodeset *busynodes;	/* active nodes; ordered by proc type */
 static char pvmtxt[512];		/* scratch for error log */
 static int ptypemask;			/* mask; we use these bits of ptype in tids */
 static u_long *nodeaddr = 0;
 static char **nodelist = 0;		/* default poe node list */
+static int *nodepart = 0;		/* processor # within node */
+#if 9
+static int *nodeconn = 0;		/* true if connection is made */
+static int *nodehost = 0;		/* host task ID */
+#endif
 static int partsize = 0;		/* total number of nodes allocated */
 
 static int mpppvminfo[SIZEHINFO];
@@ -168,11 +184,12 @@ mpp_init(argc, argv)
 	char **argv;
 {
 	struct hostent *hostaddr;
-	int 	i;
+	int 	i, j;
 	int		n;
 	struct in_addr	node_sin_addr;
-	char 	nname[128];	/* node name */
+	char 	nname[NNAMELENGTH];	/* node name */
 	char 	*p, *q;
+	int		partNum;	/* task ID number for a node */
 	char 	*plist;		/* processor list */
 
 	if ((plist = getenv("PROC_LIST"))) 
@@ -194,6 +211,11 @@ mpp_init(argc, argv)
 
 		nodeaddr = TALLOC(partsize, u_long, "nodeaddr");
 		nodelist = TALLOC(partsize, char*, "nname");
+		nodepart = TALLOC(partsize, int, "nodepart");
+#if 9
+		nodeconn = TALLOC( partsize, int, "nodeconn" );
+		nodehost = TALLOC( partsize, int, "nodehost" );
+#endif
 		p = plist;
 		i = 0;
 		while (1)
@@ -203,25 +225,55 @@ mpp_init(argc, argv)
 			if (!*p)
 				break;
 			n = (q = CINDEX(p, ':')) ? q - p : strlen(p);
-			strncpy(nname, p, n);
-			nname[n] = 0;
-			if (!(hostaddr = gethostbyname( nname )))
-				{
-				sprintf( pvmtxt, "mpp_init() can't gethostbyname() for %s\n", 
-						nname );
-				pvmlogerror( pvmtxt );
+			if (n >= NNAMELENGTH)
+				{		/* node name too long */
+				pvmlogerror( "mpp_init():  node name is too long\n" );
 				}
 			else
-				{	/* got addr, now save it */
-				BCOPY( hostaddr->h_addr_list[0], (char*)&node_sin_addr,
-					sizeof(struct in_addr));
+				{
+				strncpy(nname, p, n);
+				nname[n] = 0;
+				if (!(hostaddr = gethostbyname( nname )))
+					{
+					sprintf( pvmtxt, "mpp_init() can't gethostbyname() for %s\n", 
+							nname );
+					pvmlogerror( pvmtxt );
+					}
+				else
+					{	/* got addr, now save it */
+					BCOPY( hostaddr->h_addr_list[0], (char*)&node_sin_addr,
+						sizeof(struct in_addr));
+					}
+				partNum = 0;
+				for (j = i - 1; j >= 0; j--)
+					{	/* check for multiple procs on one node */
+					/* hash this if it takes too long */
+					if (!strcmp( nodelist[j], nname ))
+						{	/* found last reference--save info & exit */
+						partNum = nodepart[j] + 1;
+						break;
+						}
+					}
+				if (partNum >= NPARTITIONS)
+					{	/* too many task requests for this processor */
+					sprintf( pvmtxt, 
+						"mpp_init():  only %d tasks per processor allowed\n,
+							NPARTITIONS" );
+					pvmlogerror( pvmtxt );
+					}
+				else
+					{
+					nodepart[i] = partNum;
+					nodeaddr[i] = node_sin_addr.s_addr;
+#if 9
+					nodeconn[i] = 0;	/* no connection now */
+					nodehost[i] = 0;	/* zero out host task ID field */
+#endif
+					nodelist[i++] = STRALLOC(nname);
+					}
 				}
-			nodeaddr[i] = node_sin_addr.s_addr;
-			nodelist[i++] = STRALLOC(nname);
 			p += n;
 			}
-
-
 		} 
 	else 
 		pvmlogerror("mpp_init() PROC_LIST must be set for parallelism.\n");
@@ -232,15 +284,20 @@ mpp_init(argc, argv)
 	busynodes = TALLOC(1, struct nodeset, "nsets");
 	BZERO((char*)busynodes, sizeof(struct nodeset));
 	busynodes->n_link = busynodes;
-	busynodes->n_rlink = busynodes;
+	busynodes->n_rlink = busynodes;	/* make the list empty */
 
 	ptypemask = tidtmask >> (ffs(tidtmask) - 1);
-}
+}	/* mpp_init() */
 
 
 /*
  * find a set of free nodes from nodelist; assign ptype sequentially,
- * only tasks spawned together get the same ptype
+ * only tasks spawned together get the same ptype--really a partition ID
+ *
+ * the code depends on the n_first field being usable as an index into
+ * the node___ arrays, and also assumes that
+ * all nodes in a set are sequential in the same order as in the node___
+ * arrays (eg. see code just before forkexec())
  */
 struct nodeset *
 mpp_new(count, ptid)
@@ -267,7 +324,7 @@ mpp_new(count, ptid)
 			break;
 */
 		if (ptype <= sp->n_ptype)
-			ptype = sp->n_ptype + 1;
+			ptype = sp->n_ptype + 1;	/* find lowest unused ptype */
 	}
 	if (sp == busynodes && partsize - last <= count) {
 		pvmlogerror("mpp_new() not enough nodes in partition\n");
@@ -276,12 +333,12 @@ mpp_new(count, ptid)
 	}
 	for (sp2 = busynodes->n_link; sp2 != busynodes; sp2 = sp2->n_link)
 		if ((sp2->n_ptype & ptypemask) == (ptype & ptypemask))
-			break;
+			break;						/* break if ptype is in use */
 	if (sp2 != busynodes || ptype == NPARTITIONS) {
 		for (ptype = 0; ptype < NPARTITIONS; ptype++) {
 			for (sp2 = busynodes->n_link; sp2 != busynodes; sp2 = sp2->n_link)
 				if ((sp2->n_ptype & ptypemask) == (ptype & ptypemask))
-					break;
+					break;				/* search for any unused ptype */
 			if (sp2 == busynodes)
 				break;
 		}
@@ -301,11 +358,15 @@ done:
 	newp->n_ptype = ptype;
 	newp->n_ptid = ptid;
 	newp->n_alive = count;
+#if 0
 	sprintf( pvmtxt, "mpp_new() sp=%x sp->n_link=%x\n", sp, sp->n_link );
 	pvmlogerror( pvmtxt );
+#endif
 	LISTPUTBEFORE(sp, newp, n_link, n_rlink);
+#if 0
 	sprintf( pvmtxt, "mpp_new() sp=%x sp->n_link=%x\n", sp, sp->n_link );
 	pvmlogerror( pvmtxt );
+#endif
 
 	return newp;
 }
@@ -321,7 +382,7 @@ mpp_free(tp)
 	struct task *tp;
 {
 	struct nodeset *sp;
-	int ptype;
+	int PLIndex;
 #if 0
 	struct timeval tout;
 #endif
@@ -331,16 +392,21 @@ mpp_free(tp)
 	if (!TIDISNODE(tid))
 		return;
 
-	ptype = TIDTOTYPE(tid);
+	PLIndex = tid & TIDNODE;	/* get processor index (into PROC_LIST) */
 	tp->t_txq = 0;				/* don't free pvmhost's txq */
 	sp = busynodes->n_link;
+#if 0
 	sprintf( pvmtxt, "mpp_free() sp=%x sp->n_link=%x\n", sp, sp->n_link );
 	pvmlogerror( pvmtxt );
+#endif
 	for (sp = busynodes->n_link; sp != busynodes; sp = sp->n_link) {
-		sprintf(pvmtxt, "mpp_free() n_ptype = %d, ptype = %d\n",
-			sp->n_ptype, ptype );
+#if 0
+		sprintf(pvmtxt, "mpp_free() n_ptype = %d, PLIndex = %d\n",
+			sp->n_ptype, PLIndex );
 		pvmlogerror(pvmtxt);
-		if ((sp->n_ptype & ptypemask) == ptype) {
+#endif
+		/* check if index is in range of this node set */
+		if ((PLIndex >= sp->n_first) && (PLIndex < sp->n_first + sp->n_size)) {
 
 			if (pvmdebmask & PDMNODE) {
 				sprintf(pvmtxt, "mpp_free() t%x type=%ld alive=%d\n",
@@ -417,6 +483,7 @@ struct waitc_spawn *wxp;
 	char **argv;            /* arg list (argv[-1] must be there) */
 	int count;				/* how many */
 	int *tids;				/* array to store new tids */
+	int	partNum;			/* unique task ID for this processor */
 	int ptid;				/* parent task ID */
 	int ptypepart;			/* type field */
 	int j;
@@ -466,7 +533,6 @@ struct waitc_spawn *wxp;
 			err = PvmOutOfRes;
 			goto done;
 		}
-		ptypepart = (0 << (ffs(tidtmask) - 1)) | TIDONNODE;
 
 		if (argv)
 			for (nargs = 0; argv[nargs]; nargs++);
@@ -495,6 +561,8 @@ struct waitc_spawn *wxp;
 		for (j = 0; j < count; j++) 
 			{
 			av[1] = nodelist[sp->n_first + j];
+			partNum = nodepart[sp->n_first + j];
+			ptypepart = (partNum << (ffs(tidtmask) - 1)) | TIDONNODE;
 			sprintf(pvmtxt, "mppload(): Forking to %s\n", av[1]);
 			pvmlogerror(pvmtxt);
 			/* if (err = forkexec(flags, av[0], av, 0, (char **)0, &tp)) */
@@ -508,6 +576,7 @@ struct waitc_spawn *wxp;
 			if (pvmdebmask & PDMNODE) 
 				pvmlogprintf( "mpp_load() setting n_ptid to %x\n", tp->t_tid );
 			sp->n_ptid = tp->t_tid;		/* pvmhost's tid */
+			nodehost[sp->n_first + j] = tp->t_tid;
 			hosttxq = tp->t_txq;
 			hostout = tp->t_out;
 			hostpid = tp->t_pid;
@@ -578,26 +647,47 @@ done:
 
 /* Find task by socket address */
 
-struct task *mpp_find( tp )
+struct task *mpp_conn( tp )
 	struct task	*tp;
 {
 	int			i;
 	struct task	*nodetp = 0;
 	int			ptypepart;
 
+#if 0
+	sprintf(pvmtxt, "mpp_conn asked for t%x\n", tp->t_tid);
+	pvmlogerror(pvmtxt);
+#endif
+	ptypepart = (tp->t_tid & tidtmask) | TIDONNODE;
 	for (i = 0; i < partsize; i++)
 		if (nodeaddr[i] == tp->t_sad.sin_addr.s_addr)
-			{
-			ptypepart = (0 << (ffs(tidtmask) - 1)) | TIDONNODE;
-			sprintf(pvmtxt, "mpp_find looking for t%x\n", myhostpart + ptypepart + i);
+			{	/* we have an IP match--check partition */
+#if 0
+			sprintf(pvmtxt, "mpp_conn looking for t%x\n", myhostpart + ptypepart + i);
 			pvmlogerror(pvmtxt);
-			if (nodetp = task_find( myhostpart + ptypepart + i ))
-				break;	/* found match */
+#endif
+#if 9
+			if (!nodeconn[i])
+				{	/* no connection here yet */
+				ptypepart = (nodepart[i] << (ffs(tidtmask) - 1)) | TIDONNODE;
+#endif
+				if (nodetp = task_find( myhostpart + ptypepart + i ))
+#if 9
+					/* from tm_conn2 in tdpro.c */
+					if (!(nodetp->t_flag & (TF_AUTH|TF_CONN)) )
+						{
+						nodeconn[i] = 1;	/* making a connection */
+#endif
+						break;	/* found match */
+#if 9
+						}
+				}
+#endif
 			}
 	if (!nodetp)
-		pvmlogerror( "mpp_find:  Task not found\n" );
+		pvmlogerror( "mpp_conn:  Task not found\n" );
 	return nodetp;
-}	/* mpp_find() */
+}	/* mpp_conn() */
 
 
 /*
@@ -614,16 +704,32 @@ mpp_output(dummy1, dummy2)
 {
 	struct nodeset *sp, *sp2;
 	struct task *tp;
+#if 9
+    int     hostsFound;
+    int     i;
+	int		PLIndex;
+#endif
 	int ptype;
 
 	sp = busynodes->n_link;
 	for (sp = busynodes->n_link; sp != busynodes; sp = sp->n_link)
-		if ((tp = task_find(sp->n_ptid))) {
+      {
+      hostsFound = 0;
+      for (PLIndex = sp->n_first; PLIndex < sp->n_first + sp->n_size;
+            PLIndex++)
+        {   /* cycle through the list for this group of nodes */
+		if (tp = task_find(nodehost[PLIndex])) 
+            {   /* got the host's tp */
 			if (tp->t_txq->pk_link->pk_buf && tp->t_sock != -1)
 				wrk_fds_add(tp->t_sock, 2);
-		} else {
-			if (sp->n_alive) {
-				sprintf(pvmtxt, "mpp_output() pvmhost %d died!\n", sp->n_ptype);
+            hostsFound++;
+		    } 
+        }
+        if (!hostsFound) 
+            {   /* no pvmhost for this entry */
+			if (sp->n_alive) 
+                {
+				sprintf(pvmtxt, "mpp_output() pvmhost %x died for ptype %d!\n", sp->n_ptid, sp->n_ptype);
 				pvmlogerror(pvmtxt);
 				/* clean up tasks it serves */
 				ptype = sp->n_ptype & ptypemask;
@@ -634,13 +740,21 @@ mpp_output(dummy1, dummy2)
 						task_cleanup(tp->t_link);
 						task_free(tp->t_link);
 					}
-			}
-			/* pvmhost has died, destroy the node set */
+			    }
+			/* all pvmhosts have died, destroy the node set */
 			sp2 = sp;
 			sp = sp->n_rlink;
+#if 9
+			for (i = 0; i < sp2->n_size; i++)
+				{
+				nodeconn[sp2->n_first + i] = 0;	/* disconnect */
+				nodehost[sp2->n_first + i] = 0;	/* zero host task ID */
+				}
+#endif
 			LISTDELETE(sp2, n_link, n_rlink);
 			PVM_FREE(sp2);
-		}
+		    }
+      }   /* for sp... */
 	return 0;
 }
 
