@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: pvmdmimd.c,v 1.10 2002/02/21 23:19:28 pvmsrc Exp $";
+	"$Id: pvmdmimd.c,v 1.11 2005/08/22 15:13:55 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -94,6 +94,11 @@ static char rcsid[] =
 /*
  *
  * $Log: pvmdmimd.c,v $
+ * Revision 1.11  2005/08/22 15:13:55  pvmsrc
+ * Added #include <pvmtev.h> for #include global.h...  :-Q
+ * 	- submitted by Skipper Hartley <charles.l.hartley@bankofamerica.com>
+ * (Spanker=kohl)
+ *
  * Revision 1.10  2002/02/21 23:19:28  pvmsrc
  * Added new (not to be documented!) PVM_MAX_TASKS env var support.
  * 	- for Mahir Lokvancic <mahir@math.ufl.edu>.
@@ -213,6 +218,7 @@ static char rcsid[] =
 #endif
 #include <pvm3.h>
 #include <pvmproto.h>
+#include <pvmtev.h>
 #include "global.h"
 #include "pvmalloc.h"
 #include "host.h"
