@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: ddpro.c,v 1.35 1999/08/19 15:39:22 pvmsrc Exp $";
+	"$Id: ddpro.c,v 1.48 2004/01/14 18:50:55 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -36,6 +36,101 @@ static char rcsid[] =
  *	Entry points for messages from network.
  *
  * $Log: ddpro.c,v $
+ * Revision 1.48  2004/01/14 18:50:55  pvmsrc
+ * Added new AIX5* arches.
+ * (Spanker=kohl)
+ *
+ * Revision 1.47  2002/04/16 15:06:00  pvmsrc
+ * WIN32 Fixes for Multiple Domains.
+ * 	- submitted by Jigen Zhou <jigen@icemcfd.com>.
+ * (Spanker=kohl)
+ *
+ * Revision 1.46  2002/02/21 23:18:40  pvmsrc
+ * Added new (not to be documented!) PVM_MAX_TASKS env var support.
+ * 	- for Mahir Lokvancic <mahir@math.ufl.edu>.
+ * 	- forcefully limits the number of tasks that can attach to a
+ * 		pvmd, required on Solaris in rare circumstances when hard
+ * 		FD_SETSIZE limit is reached, and all hell breaks loose...
+ * 	- check return for task_new() call, can now produce NULL ptr,
+ * 		indicating PvmOutOfRes...
+ * (Spanker=kohl)
+ *
+ * Revision 1.45  2001/09/26 23:35:19  pvmsrc
+ * Added new hd_vmid to hostd struct.
+ * 	- use to override local PVM_VMID settings with hostfile "id=" option
+ * (Spanker=kohl)
+ *
+ * Revision 1.44  2001/09/26 21:22:16  pvmsrc
+ * Added Handling for Optional Virtual Machine ID.
+ * 	- extra vmid comes through with SM_STHOST message (after wincmd).
+ * 	- instruct user to type VMID on remote pvmd stdin for manual startup
+ * 	- in phase1(), after potential rsh/rexec, write VMID env string
+ * 		to remote pvmd's stdin.
+ * (Spanker=kohl)
+ *
+ * Revision 1.43  2001/05/11 17:31:56  pvmsrc
+ * Cast getcwd() call, in case header file sucks.
+ * 	- eliminates warning message on compile...
+ * (Spanker=kohl)
+ *
+ * Revision 1.42  2001/04/23 14:16:13  pvmsrc
+ * Added new working directory option to pvm_spawn().
+ * 	- use "where" argument to cram in working directory,
+ * 		e.g. where = "msr.epm.ornl.gov:/home/user/project/bozo"
+ * 	- TM_SPAWN strips out working directory & creates PVMSPAWNWD env var
+ * 	- exectasks() (called by DM_EXEC or SM_EXEC) checks for env var
+ * 		and does a chdir() (even uses getcwd() to reset directory :-).
+ * 	- should not introduce any run-time incompatibility with older
+ * 		PVM releases.
+ * 	- PvmTaskHost or PvmTaskArch flags need not be used, i.e.
+ * 		pvm_spawn( "foo", 0, PvmTaskDefault, ":/tmp", 1, &tid ) works.
+ * (Spanker=kohl)
+ *
+ * Revision 1.41  2001/02/07 23:14:02  pvmsrc
+ * First Half of CYGWIN Check-ins...
+ * (Spanker=kohl)
+ *
+ * Revision 1.40  2000/06/16 16:27:32  pvmsrc
+ * DAMN.  The seemingly cool and efficient tp->t_flag / TF_MBNOTIFY
+ * solution is not as cool as previously thought.
+ * 	- each pvmd only keeps a *local* tasks table...!  D-OH!
+ * 	- need to just search the wait context list for an existing
+ * 		WT_TASKX mbox notify, as previously feared.
+ * 	- already checking wait context list for WT_RECVINFO, so this
+ * 		is not too terrible...
+ * 	- Damn, though...
+ * Removed TF_MBNOTIFY contant - now fricking useless.
+ * (Spanker=kohl)
+ *
+ * Revision 1.39  2000/06/13 22:37:56  pvmsrc
+ * In dm_db():
+ * 	- on successful insert, check whether task already had an mbox
+ * 		notify (for mb_tidy()) set up.
+ * 	- after first such notify / waitc created, set tp->t_flag
+ * 		TF_MBNOTIFY bit.
+ * 	- this avoids a HUGE number of redundant notifies for multiple
+ * 		inserts by the same task.  D-Oh!
+ * (Spanker=kohl)
+ *
+ * Revision 1.38  2000/02/17 23:12:08  pvmsrc
+ * *** Changes for new BEOLIN port ***
+ * 	- MPP-like, similar to SP2, etc.
+ * 	- submitted by Paul Springer <pls@smokeymt.jpl.nasa.gov>.
+ * 	- format-checked & cleaned up by Jeembo...  :-)
+ * (Spanker=kohl)
+ *
+ * Revision 1.37  2000/02/16 21:59:38  pvmsrc
+ * Fixed up #include <sys/types.h> stuff...
+ * 	- use <bsd/sys/types.h> for IMA_TITN...
+ * 	- #include before any NEEDMENDIAN #includes...
+ * (Spanker=kohl)
+ *
+ * Revision 1.36  2000/02/10 23:53:35  pvmsrc
+ * Added new PvmIPLoopback error code:
+ * 	- Master Host IP Address tied to Loopback.
+ * 	- check for this case in addhosts(), don't even TRY to add hosts...
+ * (Spanker=kohl)
+ *
  * Revision 1.35  1999/08/19 15:39:22  pvmsrc
  * Whoa...  New wincmd stuff was whacking addhost protocol!
  * 	- *always* pack in something for wincmd, else the attempt to unpack
@@ -276,6 +371,12 @@ static char rcsid[] =
  */
 
 
+#ifdef IMA_TITN
+#include <bsd/sys/types.h>
+#else
+#include <sys/types.h>
+#endif
+
 #ifdef NEEDMENDIAN
 #include <machine/endian.h>
 #endif
@@ -285,26 +386,37 @@ static char rcsid[] =
 #ifdef NEEDSENDIAN
 #include <sys/endian.h>
 #endif
-#ifndef WIN32
+
+#ifdef WIN32
+#include "pvmwin.h"
+#endif
+
+#if defined(WIN32) || defined(CYGWIN)
+#include "..\xdr\types.h"
+#include "..\xdr\xdr.h"
+#else
 #include <rpc/types.h>
 #include <rpc/xdr.h>
-#include <sys/time.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <netdb.h>
-#else 
-#include "pvmwin.h"
+#endif
+
+#ifdef WIN32
 #include <sys/stat.h>
 #include <time.h>
 #include <direct.h>
 #include <errno.h>
+#else 
+#include <sys/time.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <netdb.h>
 #endif
-#include <sys/types.h>
+
 #ifdef	SYSVSTR
 #include <string.h>
 #else
 #include <strings.h>
 #endif
+
 #include <errno.h>
 #include <stdio.h>
 
@@ -316,7 +428,9 @@ static char rcsid[] =
 #include "waitc.h"
 #include "task.h"
 #include "listmac.h"
-#if defined(IMA_PGON) || defined(IMA_I860) || defined(IMA_CM5) || defined(SHMEM) || defined(IMA_SP2MPI) || defined(IMA_AIX4SP2)
+#if defined(IMA_PGON) || defined(IMA_I860) || defined(IMA_CM5) \
+	|| defined(SHMEM) || defined(IMA_SP2MPI) || defined(IMA_AIX4SP2) \
+	|| defined(IMA_AIX5SP2) || defined(IMA_BEOLIN)
 #include "pvmdmp.h"
 #endif
 #include "bfunc.h"
@@ -742,6 +856,7 @@ addhosts(mp, rmp)
 	int *tids;
 	char *winpvmdpath;
 	char *pvmdpath;
+	char *vmid;
 	char *buf;
 	int len;
 
@@ -803,6 +918,26 @@ addhosts(mp, rmp)
 		PVM_FREE(buf);
 	}
 
+	/*
+	* verify we have a chance to add these babies...
+	* check whether our IP is "real" or just loopback
+	*/
+
+	hp = hosts->ht_hosts[hosts->ht_local];
+
+	if ( hp->hd_sad.sin_addr.s_addr == htonl(0x7f000001) ) {
+
+		/* damn, we're hosed.  bail on host adds with new */
+		/* PvmIPLoopback error code... */
+
+		for (i = 0; i < count; i++) {
+			hp = wxp->w_hosts[i];
+			if (hp->hd_err)
+				continue;
+			hp->hd_err = PvmIPLoopback;
+		}
+	}
+
 	/*
 	* lookup IP addresses  XXX we already have some of them
 	*/
@@ -968,6 +1103,15 @@ addhosts(mp, rmp)
 		/* be sure to pack SOMETHING, dammit */
 		else
 			pkstr(mp2, "");
+
+		/* Include VMID (If Any) */
+		if (hp->hd_vmid)
+			pkstr(mp2, hp->hd_vmid);
+		else if (vmid = getenv("PVM_VMID"))
+			pkstr(mp2, vmid);
+		/* be sure to pack SOMETHING, dammit */
+		else
+			pkstr(mp2, "");
 	}
 	mp2->m_tag = SM_STHOST;
 
@@ -1117,7 +1261,10 @@ hosterforkexec(tid, name, tpp)
 	if (stat(name, &sb) == -1) 
 		return PvmNoFile;
 
-	tp = task_new(tid);		
+	if ((tp = task_new(tid)) == NULL) {
+		pvmlogperror("forkexec_hoster() too many tasks?\n");
+		return PvmOutOfRes;
+	}
 
 	p = myenv;
 	q = environ;
@@ -1262,6 +1409,8 @@ exectasks(mp, rmp, schtid)
 	struct waitc_spawn *wxp;	/* new task parameters */
 	int munge_tenv = 0;
 	char tmp[255];
+	char *wd = 0;
+	char *savewd = 0;
 
 	wxp = TALLOC(1, struct waitc_spawn, "waix");
 	BZERO((char*)wxp, sizeof(struct waitc_spawn));
@@ -1324,9 +1473,19 @@ exectasks(mp, rmp, schtid)
 	for (i = 0; i < wxp->w_nenv; i++)
 		if (upkstralloc(mp, &wxp->w_env[i]))
 			goto bad;
+
 	if ( upkuint(mp, &wxp->w_instance) || upkuint(mp, &wxp->w_outof))
 		goto bad;
 
+	/* check for spawn working directory */
+
+	for (i = 0; i < wxp->w_nenv; i++)
+		if ( !strncmp( "PVMSPAWNWD=", wxp->w_env[i],
+				strlen("PVMSPAWNWD=") ) )
+			wd = STRALLOC( wxp->w_env[i] + strlen("PVMSPAWNWD=") );
+
+	/* munge env for tracing stuff */
+
 	if ( munge_tenv ) {
 		sprintf( tmp, "PVMTMASK=%s", pvmtracer.tmask );
 		pvmenvinsert( &(wxp->w_env), tmp );
@@ -1345,7 +1504,14 @@ exectasks(mp, rmp, schtid)
 
 	wxp->w_sched = schtid;
 
-#if defined(IMA_PGON) || defined(IMA_SP2MPI) || defined(IMA_AIX4SP2)
+	/* change to desired working directory (if specified) */
+	if (wd) {
+		savewd = (char *) getcwd( (char *) NULL, 255 );
+		chdir( wd );
+	}
+
+#if defined(IMA_PGON) || defined(IMA_SP2MPI) || defined(IMA_AIX4SP2) \
+		|| defined(IMA_AIX5SP2) || defined(IMA_BEOLIN)
 	if (!(wxp->w_flags & PvmMppFront))
 	{
 		mpp_load(wxp);
@@ -1356,6 +1522,10 @@ exectasks(mp, rmp, schtid)
 		ppi_load(wxp);
 	}
 
+	/* go back to original directory (if getcwd() was successful) */
+	if (savewd)
+		chdir( savewd );
+
 for (i = 0; i < wxp->w_veclen; i++) {
 		if (wxp->w_vec[i] > 0) {
 			if (wxp->w_trctid > 0) {
@@ -1390,6 +1560,8 @@ cleanup:
 	if (wxp->w_argv)
 		*--wxp->w_argv = 0;
 	free_wait_spawn(wxp);
+	if (wd)
+		PVM_FREE(wd);
 	return 0;
 }
 
@@ -2791,6 +2963,7 @@ dm_db(hp, mp)
 	int found;
 	int cc;
 	int i;
+	int notified;
 
 	hp = hp;
 
@@ -2812,26 +2985,9 @@ dm_db(hp, mp)
 		if ((req = mb_insert(tid, name, req, flags, mp3)) < 0)
 			pmsg_unref(mp3);
 		else {
-			/* dummy notify for clean up */
-			wp = wait_new(WT_TASKX);
-			wp->wa_on = tid;
-			wp->wa_tid = pvmmytid;
-			wp->wa_dep = 0;
-			wp->wa_mesg = (struct pmsg *) NULL;
-
-			/* pass on to non-master host */
-			hp2 = tidtohost(hosts, tid);
-			if ( hp2 && hp2->hd_hostpart != myhostpart ) {
-				mp4 = mesg_new(0);
-				pkint(mp4, PvmTaskExit);
-				pkint(mp4, tid);
-				mp4->m_dst = hp2->hd_hostpart | TIDPVMD;
-				mp4->m_tag = DM_NOTIFY;
-				mp4->m_wid = wp->wa_wid;
-				sendmessage(mp4);
-			}
 
 			/* check for any pending requests for this mbox entry */
+			notified = 0;
 			for (wp = waitlist->wa_link; wp != waitlist; wp = wp2) {
 				wp2 = wp->wa_link;
 				if (wp->wa_kind == WT_RECVINFO) {
@@ -2853,7 +3009,35 @@ dm_db(hp, mp)
 						}
 					}
 				}
+				/* check if task needs mbox notify for mb_tidy()... */
+				else if (wp->wa_kind == WT_TASKX) {
+					if ( wp->wa_on == tid && wp->wa_tid == pvmmytid )
+						notified++;
+				}
 			}
+
+			/* create mbox notify for mb_tidy() cleanup... */
+			if ( !notified ) {
+				/* dummy notify for clean up */
+				wp = wait_new(WT_TASKX);
+				wp->wa_on = tid;
+				wp->wa_tid = pvmmytid;
+				wp->wa_dep = 0;
+				wp->wa_mesg = (struct pmsg *) NULL;
+
+				/* pass on to non-master host */
+				hp2 = tidtohost(hosts, tid);
+				if ( hp2 && hp2->hd_hostpart != myhostpart ) {
+					mp4 = mesg_new(0);
+					pkint(mp4, PvmTaskExit);
+					pkint(mp4, tid);
+					mp4->m_dst = hp2->hd_hostpart | TIDPVMD;
+					mp4->m_tag = DM_NOTIFY;
+					mp4->m_wid = wp->wa_wid;
+					sendmessage(mp4);
+				}
+			}
+
 		}
 		pkint(mp2, req);
 		break;
