@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: global.c,v 1.16 1999/07/08 18:59:52 kohl Exp $";
+	"$Id: global.c,v 1.19 2002/07/30 15:35:04 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -36,6 +36,20 @@ static char rcsid[] =
  *	General PVM Globals.
  *
  * $Log: global.c,v $
+ * Revision 1.19  2002/07/30 15:35:04  pvmsrc
+ * Enhanced PvmIPLoopback error text - "pvm3/"Readme file...  Duh...
+ * (Spanker=kohl)
+ *
+ * Revision 1.18  2001/02/07 23:14:03  pvmsrc
+ * First Half of CYGWIN Check-ins...
+ * (Spanker=kohl)
+ *
+ * Revision 1.17  2000/02/10 23:53:34  pvmsrc
+ * Added new PvmIPLoopback error code:
+ * 	- Master Host IP Address tied to Loopback.
+ * 	- check for this case in addhosts(), don't even TRY to add hosts...
+ * (Spanker=kohl)
+ *
  * Revision 1.16  1999/07/08 18:59:52  kohl
  * Fixed "Log" keyword placement.
  * 	- indent with " * " for new CVS.
@@ -111,12 +125,10 @@ static char rcsid[] =
 #include <stdio.h>
 
 #include <pvm3.h>
-#ifdef WIN32
-#ifndef _XDR_HEADERS
-#define _XDR_HEADERS
+
+#if defined(WIN32) || defined(CYGWIN)
 #include "..\xdr\types.h"
 #include "..\xdr\xdr.h"
-#endif
 #else
 #include <rpc/types.h>
 #include <rpc/xdr.h>
@@ -177,6 +189,7 @@ char *pvm_errlist[] = {
 	"Already Exists",
 	"Hoster must run on master host",
 	"Spawning parent set PvmNoParent",
+	"Master Host IP Address is Loopback! (See pvm3/Readme)",
 };
 
 int pvm_nerr =							/* exported num of errors */
