@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: host.c,v 1.21 2004/01/14 18:50:55 pvmsrc Exp $";
+	"$Id: host.c,v 1.22 2005/08/22 15:13:17 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -36,6 +36,11 @@ static char rcsid[] =
  *	Host table functions.
  *
  * $Log: host.c,v $
+ * Revision 1.22  2005/08/22 15:13:17  pvmsrc
+ * Added #include <pvmtev.h> for #include global.h...  :-Q
+ * 	- submitted by Skipper Hartley <charles.l.hartley@bankofamerica.com>
+ * (Spanker=kohl)
+ *
  * Revision 1.21  2004/01/14 18:50:55  pvmsrc
  * Added new AIX5* arches.
  * (Spanker=kohl)
@@ -224,6 +229,7 @@ static char rcsid[] =
 #include "pmsg.h"
 #include "pkt.h"
 #include "bfunc.h"
+#include <pvmtev.h>
 #include "global.h"
 
 #ifndef	max
