@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: hoster.c,v 1.20 2001/09/27 21:25:09 pvmsrc Exp $";
+	"$Id: hoster.c,v 1.22 2007/04/19 23:14:34 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -36,6 +36,17 @@ static char rcsid[] =
  *	Slave pvmd starter.
  *
  * $Log: hoster.c,v $
+ * Revision 1.22  2007/04/19 23:14:34  pvmsrc
+ * Added modern blanket header files to eliminate warnings on _exit()...
+ * 	- #include <unistd.h>
+ * 	- #include <stdlib.h>
+ * (Spanker=kohl)
+ *
+ * Revision 1.21  2005/08/22 15:13:18  pvmsrc
+ * Added #include <pvmtev.h> for #include global.h...  :-Q
+ * 	- submitted by Skipper Hartley <charles.l.hartley@bankofamerica.com>
+ * (Spanker=kohl)
+ *
  * Revision 1.20  2001/09/27 21:25:09  pvmsrc
  * BEOSCYLD port.
  * 	- submitted by Joe Vitale <vitale@scyld.com>.
@@ -238,6 +249,8 @@ static char rcsid[] =
 
 #include <fcntl.h>
 #include <stdio.h>
+#include <unistd.h>
+#include <stdlib.h>
 #include <errno.h>
 #include <ctype.h>
 #ifdef	SYSVSTR
@@ -255,6 +268,7 @@ static char rcsid[] =
 #include "listmac.h"
 #include "tvdefs.h"
 #include "bfunc.h"
+#include <pvmtev.h>
 #include "global.h"
 
 #ifdef IMA_BEOSCYLD
