@@ -1,12 +1,16 @@
 
+static char rcsid[] =
+	"$Id: imalloc.c,v 1.5 1998/03/24 20:16:17 pvmsrc Exp $";
+
 /*
- *         PVM version 3.3:  Parallel Virtual Machine System
+ *         PVM version 3.4:  Parallel Virtual Machine System
  *               University of Tennessee, Knoxville TN.
  *           Oak Ridge National Laboratory, Oak Ridge TN.
  *                   Emory University, Atlanta GA.
- *      Authors:  A. L. Beguelin, J. J. Dongarra, G. A. Geist,
- *    W. C. Jiang, R. J. Manchek, B. K. Moore, and V. S. Sunderam
- *                   (C) 1992 All Rights Reserved
+ *      Authors:  J. J. Dongarra, G. E. Fagg, M. Fischer
+ *          G. A. Geist, J. A. Kohl, R. J. Manchek, P. Mucci,
+ *         P. M. Papadopoulos, S. L. Scott, and V. S. Sunderam
+ *                   (C) 1997 All Rights Reserved
  *
  *                              NOTICE
  *
@@ -131,7 +135,6 @@ struct glob {
 #define	OBALLOC		1	/* ob was just alloced - cleared by dump() */
 #define	OBREALLOC	2	/* ob was just realloced - cleared by dump() */
 
-static char rcsid[] = "$Id: imalloc.c,v 1.3 1994/11/07 21:33:32 manchek Exp $";
 
 /* default values */
 
@@ -162,6 +165,7 @@ static int globavail = STATICGLOBS;
 *	Found an inconsistency; bail.
 */
 
+void
 i_choke()
 {
 #if	DIEONERROR
@@ -296,7 +300,7 @@ i_free(loc)
 	he = &hashtbl[HASH(loc)];
 	for (preob = 0, ob = *he; ob && ob->base != loc; preob = ob, ob = ob->next);
 	if (!ob) {
-		(void)sprintf(msbuf, "i_free: bogus loc=0x%x\n", loc);
+		(void)sprintf(msbuf, "i_free: bogus loc=0x%lx\n", (long) loc);
 		(void)SWRITE(debfd, msbuf);
 		i_choke();
 		return 0;
@@ -307,14 +311,15 @@ i_free(loc)
 
 	for (i = ob->lop, ptr -= i; i > 0; i--)
 		if ((0xff & (int)(*ptr++)) != (0xff & NEXTRN(rs))) {
-			(void)sprintf(msbuf, "i_free: scribbled in 0x%x[%d]\n", loc, -i);
+			(void)sprintf(msbuf, "i_free: scribbled in 0x%lx[%d]\n",
+				(long) loc, -i);
 			(void)SWRITE(debfd, msbuf);
 			i_choke();
 		}
 	for (i = ob->hip, ptr += ob->len; i > 0; i--)
 		if ((0xff & (int)(*ptr++)) != (0xff & NEXTRN(rs))) {
-			(void)sprintf(msbuf, "i_free: scribbled in 0x%x[%d+%d]\n",
-				loc, ob->len, ob->hip - i);
+			(void)sprintf(msbuf, "i_free: scribbled in 0x%lx[%d+%d]\n",
+				(long) loc, ob->len, ob->hip - i);
 			(void)SWRITE(debfd, msbuf);
 			i_choke();
 		}
@@ -390,7 +395,8 @@ i_realloc(loc, len)
 	he = &hashtbl[HASH(loc)];
 	for (preob = 0, ob = *he; ob && ob->base != loc; preob = ob, ob = ob->next);
 	if (!ob) {
-		(void)sprintf(msbuf, "i_realloc: bogus loc=0x%x\n", loc);
+		(void)sprintf(msbuf, "i_realloc: bogus loc=0x%lx\n",
+			(long) loc);
 		(void)SWRITE(debfd, msbuf);
 		i_choke();
 		return (char*)0;
@@ -401,14 +407,16 @@ i_realloc(loc, len)
 
 	for (i = ob->lop, ptr -= i; i > 0; i--)
 		if ((0xff & (int)(*ptr++)) != (0xff & NEXTRN(rs))) {
-			(void)sprintf(msbuf, "i_realloc: scribbled in 0x%x[%d]\n", loc, -i);
+			(void)sprintf(msbuf, "i_realloc: scribbled in 0x%lx[%d]\n",
+				(long) loc, -i);
 			(void)SWRITE(debfd, msbuf);
 			i_choke();
 		}
 	for (i = ob->hip, ptr += ob->len; i > 0; i--)
 		if ((0xff & (int)(*ptr++)) != (0xff & NEXTRN(rs))) {
-			(void)sprintf(msbuf, "i_realloc: scribbled in 0x%x[%d+%d]\n",
-				loc, ob->len, ob->hip - i);
+			(void)sprintf(msbuf,
+				"i_realloc: scribbled in 0x%lx[%d+%d]\n",
+				(long) loc, ob->len, ob->hip - i);
 			(void)SWRITE(debfd, msbuf);
 			i_choke();
 		}
@@ -453,7 +461,7 @@ i_realloc(loc, len)
 *	Convert byte string to printable characters.
 */
 
-static
+static void
 ascdump(o, p, e)
 	char **o;		/* addr of pointer to output space (passed back) */
 	char *p;		/* string to convert */
@@ -483,6 +491,7 @@ ascdump(o, p, e)
 *	Dump the table of contents of allocated buffers.
 */
 
+void
 i_dump(how)
 	int how;			/* != 0 also do sanity checking */
 {
@@ -512,16 +521,17 @@ i_dump(how)
 				for (i = ob->lop, ptr -= i; i > 0; i--)
 					if ((0xff & (int)(*ptr++)) != (0xff & NEXTRN(rs))) {
 						(void)sprintf(msbuf,
-							"%5d 0x%08x[%d]: scribbled in [%d]\n",
-							ob->id, ob->base, ob->len, -i);
+							"%5d 0x%08lx[%d]: scribbled in [%d]\n",
+							ob->id, (long) ob->base, ob->len, -i);
 						(void)SWRITE(debfd, msbuf);
 						err++;
 					}
 				for (i = ob->hip, ptr += ob->len; i > 0; i--)
 					if ((0xff & (int)(*ptr++)) != (0xff & NEXTRN(rs))) {
 						(void)sprintf(msbuf,
-							"%5d 0x%08x[%d]: scribbled in [%d+%d]\n",
-							ob->id, ob->base, ob->len, ob->len, ob->hip - i);
+							"%5d 0x%08lx[%d]: scribbled in [%d+%d]\n",
+							ob->id, (long) ob->base, ob->len, ob->len,
+							ob->hip - i);
 						(void)SWRITE(debfd, msbuf);
 						err++;
 					}
@@ -529,12 +539,12 @@ i_dump(how)
 			if (!err) {
 				strncpy(tagstr, ob->tag, 4);
 				tagstr[4] = 0;
-				sprintf(msbuf, "%5d%c%4s 0x%08x[%4d]",
+				sprintf(msbuf, "%5d%c%4s 0x%08lx[%4d]",
 					ob->id,
 					(ob->flg & OBALLOC ? '*' :
 						(ob->flg & OBREALLOC ? '+' : ' ')),
 					tagstr,
-					ob->base, ob->len);
+					(long) ob->base, ob->len);
 				r = msbuf + strlen(msbuf);
 				*r++ = ' ';
 				if ((i = ob->len) > 24)
