@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: lpvm.c,v 1.69 2004/01/14 18:50:55 pvmsrc Exp $";
+	"$Id: lpvm.c,v 1.73 2009/01/30 21:23:24 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -36,6 +36,28 @@ static char rcsid[] =
  *	Libpvm core for unix environment.
  *
  * $Log: lpvm.c,v $
+ * Revision 1.73  2009/01/30 21:23:24  pvmsrc
+ * Fixed up insecure usage of fopen() for creating/writing/appending files.
+ * 	- replace with open(...O_EXCL...) and fdopen()...
+ * Fixed improper return code wrangling in pvmbeatask()...
+ * 	- always return PvmSysErr on pvmd communication failure...  :-}
+ * (Spanker=kohl)
+ *
+ * Revision 1.72  2009/01/22 23:18:36  pvmsrc
+ * Updated version for BEOLIN from Paul Springer...
+ * (Spanker=kohl)
+ *
+ * Revision 1.71  2007/04/19 23:14:34  pvmsrc
+ * Added modern blanket header files to eliminate warnings on _exit()...
+ * 	- #include <unistd.h>
+ * 	- #include <stdlib.h>
+ * (Spanker=kohl)
+ *
+ * Revision 1.70  2005/05/18 17:56:27  pvmsrc
+ * Added calls to pvmchkuid()...
+ * 	- keep people from running PVM as root...!  :-o
+ * (Spanker=kohl)
+ *
  * Revision 1.69  2004/01/14 18:50:55  pvmsrc
  * Added new AIX5* arches.
  * (Spanker=kohl)
@@ -563,6 +585,8 @@ static char rcsid[] =
 #endif
 
 #include <stdio.h>
+#include <unistd.h>
+#include <stdlib.h>
 
 #ifdef IMA_TITN
 #include <bsd/sys/types.h>
@@ -3049,6 +3073,7 @@ pvmbeatask()
 		cc = PvmSysErr;
 		goto bail2;
 	}
+	pvmchkuid( pvm_useruid );
 #else
 	if (!username)
 		username = MyGetUserName();
@@ -3090,10 +3115,11 @@ pvmbeatask()
 #ifndef NOPROT
 	(void)PVMTMPNAMFUN(authfn);
 #ifdef IMA_OS2
-	if ((authfd = open(authfn, O_RDWR|O_CREAT|O_TRUNC, 0600)) == -1) {
+	if ((authfd = open(authfn, O_RDWR|O_CREAT|O_EXCL|O_TRUNC, 0600)) == -1)
 #else
-	if ((authfd = open(authfn, O_RDONLY|O_CREAT|O_TRUNC, 0600)) == -1) {
+	if ((authfd = open(authfn, O_RDONLY|O_CREAT|O_EXCL|O_TRUNC, 0600)) == -1)
 #endif
+	{
 		pvmlogperror(authfn);
 		pvmlogerror("pvmbeatask() can't creat t-auth file\n");
 		cc = PvmSysErr;
@@ -3121,6 +3147,7 @@ pvmbeatask()
 	pvm_upkint(&cc, 1, 1);
 	if (!cc) {
 		pvmlogerror("pvmbeatask() pvmd refuses connection\n");
+		cc = PvmSysErr;
 		goto bail;
 	}
 
@@ -3184,6 +3211,7 @@ pvmbeatask()
 	pvm_upkint(&cc, 1, 1);
 	if (!cc) {
 		pvmlogerror("pvmbeatask() pvmd refuses connection\n");
+		cc = PvmSysErr;
 		goto bail;
 	}
 #endif /* IMA_MPP */
@@ -3278,6 +3306,12 @@ pvmbeatask()
 	pvm_upkstr(buf);
 
 #ifdef IMA_BEOLIN
+	hex_inadport(buf, &pvmourinet);	/* fixed to pass proper address */
+	if (pvmdebmask & PDMROUTE)
+		{
+		pvmlogprintf( "mroute(): pvmourinet is %s\n", inadport_hex( &pvmourinet ) );
+		}
+#if 0
 	if (gethostname(namebuf, sizeof(namebuf)-1) == -1) {
 		pvmlogerror("pvmbeatask() can't gethostname()\n");
 		hex_inadport(buf, &pvmourinet);
@@ -3294,9 +3328,10 @@ pvmbeatask()
 					sizeof(struct in_addr));
 		}
 	}
+#endif
 #else
 	hex_inadport(buf, &pvmourinet);
-#endif
+#endif	/* IMA_BEOLIN */
 
 	pvmourinet.sin_family = AF_INET;
 	pvmourinet.sin_port = 0;
@@ -3534,6 +3569,7 @@ pvm_start_pvmd(argc, argv, block)
 		cc = PvmSysErr;
 		goto bail;
 	}
+	pvmchkuid( pvm_useruid );
 #else
 	if (!username) 
 		username = MyGetUserName();
