@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: lpvmcat.c,v 1.11 1999/07/08 18:59:56 kohl Exp $";
+	"$Id: lpvmcat.c,v 1.14 2001/02/07 23:14:06 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -36,6 +36,20 @@ static char rcsid[] =
  *	Child task output collection.
  *
  * $Log: lpvmcat.c,v $
+ * Revision 1.14  2001/02/07 23:14:06  pvmsrc
+ * First Half of CYGWIN Check-ins...
+ * (Spanker=kohl)
+ *
+ * Revision 1.13  2000/02/16 21:59:43  pvmsrc
+ * Fixed up #include <sys/types.h> stuff...
+ * 	- use <bsd/sys/types.h> for IMA_TITN...
+ * 	- #include before any NEEDMENDIAN #includes...
+ * (Spanker=kohl)
+ *
+ * Revision 1.12  1999/11/08 17:44:31  pvmsrc
+ * SGI compiler cleanup.
+ * (Spanker=kohl)
+ *
  * Revision 1.11  1999/07/08 18:59:56  kohl
  * Fixed "Log" keyword placement.
  * 	- indent with " * " for new CVS.
@@ -115,6 +129,7 @@ static char rcsid[] =
 
 #include <stdio.h>
 #ifdef NEEDMENDIAN
+#include <sys/types.h>
 #include <machine/endian.h>
 #endif
 #ifdef NEEDENDIAN
@@ -125,12 +140,10 @@ static char rcsid[] =
 #endif
 
 #include <pvm3.h>
-#ifdef WIN32
-#ifndef _XDR_HEADERS
-#define _XDR_HEADERS
+
+#if defined(WIN32) || defined(CYGWIN)
 #include "..\xdr\types.h"
 #include "..\xdr\xdr.h"
-#endif
 #else
 #include <rpc/types.h>
 #include <rpc/xdr.h>
@@ -143,6 +156,7 @@ static char rcsid[] =
 #include <strings.h>
 #define	CINDEX(s,c)	index(s,c)
 #endif
+
 #include <signal.h>
 #include <pvmproto.h>
 #include "pvmalloc.h"
@@ -285,7 +299,6 @@ static int
 pvmflusho()
 {
 	struct tobuf *op;
-	int cc;
 
 	if (outlogff) {
 		if (tobuflist && tobuflist->o_link != tobuflist) {
@@ -295,7 +308,7 @@ pvmflusho()
 
 	/* XXX mroute() does return after ctrl messages received */
 
-				if ((cc = mroute(0, 0, 0, (struct timeval *)0)) < 0)
+				if ( mroute(0, 0, 0, (struct timeval *)0) < 0 )
 					break;
 			}
 		}
