@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: lpvmmimd.c,v 1.25 2004/01/14 18:50:57 pvmsrc Exp $";
+	"$Id: lpvmmimd.c,v 1.26 2005/05/18 17:56:28 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -36,6 +36,11 @@ static char rcsid[] =
  *	Libpvm core for MPP environment.
  *
  * $Log: lpvmmimd.c,v $
+ * Revision 1.26  2005/05/18 17:56:28  pvmsrc
+ * Added calls to pvmchkuid()...
+ * 	- keep people from running PVM as root...!  :-o
+ * (Spanker=kohl)
+ *
  * Revision 1.25  2004/01/14 18:50:57  pvmsrc
  * Added new AIX5* arches.
  * (Spanker=kohl)
@@ -1341,6 +1346,8 @@ pvmbeatask()
 		return PvmSysErr;
 	}
 
+	pvmchkuid( pvm_useruid );
+
 #ifdef IMA_CM5
 	CMMD_enable_host();
 	CMMD_receive_bc_from_host(pvminfo, sizeof(pvminfo));
