@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: lpvmshmem.c,v 1.47 2004/01/14 18:50:57 pvmsrc Exp $";
+	"$Id: lpvmshmem.c,v 1.50 2009/01/30 21:22:46 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -36,6 +36,22 @@ static char rcsid[] =
  *	Libpvm core for MPP environment.
  *
  * $Log: lpvmshmem.c,v $
+ * Revision 1.50  2009/01/30 21:22:46  pvmsrc
+ * Fixed up insecure usage of fopen() for creating/writing/appending files.
+ * 	- replace with open(...O_EXCL...) and fdopen()...
+ * (Spanker=kohl)
+ *
+ * Revision 1.49  2006/10/09 17:05:51  pvmsrc
+ * Fixed long-standing typo - no one must ever use this stuff...!
+ * 	- missing "||" before last "defined(IMA_AIX5MP)"...  :-Q
+ * 	- submitted by "Richard A. Roberts " <roberts@asc.hpc.mil>
+ * (Spanker=kohl)
+ *
+ * Revision 1.48  2005/05/18 17:56:29  pvmsrc
+ * Added calls to pvmchkuid()...
+ * 	- keep people from running PVM as root...!  :-o
+ * (Spanker=kohl)
+ *
  * Revision 1.47  2004/01/14 18:50:57  pvmsrc
  * Added new AIX5* arches.
  * (Spanker=kohl)
@@ -1487,6 +1503,7 @@ pvmbeatask()
 	int key, firstkeytried;
 	int mytid;
 	char *pvmtmp;
+	int fd;
 	TEV_DECLS
 
 	if (pvmmytid != -1)
@@ -1501,6 +1518,8 @@ pvmbeatask()
 		return PvmSysErr;
 	}
 
+	pvmchkuid( pvm_useruid );
+
 	if (p = getenv("PVMTASKDEBUG")) {
 		pvmdebmask = pvmxtoi(p);
 		if (pvmdebmask) {
@@ -1522,8 +1541,12 @@ pvmbeatask()
 	else
 #endif
 		sprintf(fname, "%s/pvmt.%d", pvmtmp, pvm_useruid);
-		if ((logfp = fopen(fname, "a")) == NULL)
+		if ((fd = open( fname,
+				O_RDWR|O_CREAT|O_APPEND|O_EXCL|O_TRUNC, 0600 )) < 0) {
 			pvmlogerror("pvmbeatask() can't open log file\n");
+		}
+		else if ((logfp = fdopen( fd, "a" )) == NULL)
+			pvmlogerror("pvmbeatask() can't fdopen log file\n");
 #endif
 
 	/*
@@ -2096,6 +2119,8 @@ pvm_start_pvmd(argc, argv, block)
 		goto bail;
 	}
 
+	pvmchkuid( pvm_useruid );
+
 	if (!(sfn = pvmdsockfile())) {
 		pvmlogerror("pvm_start_pvmd() pvmdsockfile() failed\n");
 		cc = PvmSysErr;
@@ -2352,7 +2377,7 @@ dynbuf(tid, len)
 	if (!(ph = (struct shmpghdr *)pp->p_dbuf)) {
 		pvmtmp = pvmgettmp();
 		sprintf(fname, PVMSHMFILE, pvmtmp, tid);
-		if ((fd = open(fname, O_CREAT|O_RDWR, 0600)) == -1 ||
+		if ((fd = open(fname, O_CREAT|O_EXCL|O_RDWR, 0600)) == -1 ||
 		(pp->p_dbuf = (char *)mmap(0, max(len,SHMBUFSIZE), PROT_READ|PROT_WRITE,
 #if defined(IMA_SGIMP) || defined(IMA_SGIMP6) || defined(IMA_SGIMP64)
 		MAP_SHARED|MAP_AUTOGROW, fd, 0)) == (char *)-1L)
@@ -2376,7 +2401,7 @@ dynbuf(tid, len)
 				return (char *)-1L;
 #ifdef IMA_SUNMP
 	} else if (pp->p_dlen < len) {
-		if ((fd = open(fname, O_CREAT|O_RDWR, 0600)) == -1) {
+		if ((fd = open(fname, O_CREAT|O_EXCL|O_RDWR, 0600)) == -1) {
 			pvmlogperror(fname);
 			return (char *)-1L;
 		}
@@ -2859,7 +2884,7 @@ sleep_dammit( msecs )
 int msecs;
 {
 #if defined(IMA_SUNMP) || defined(IMA_RS6KMP) || defined(IMA_AIX4MP) \
-		defined(IMA_AIX5MP)
+		|| defined(IMA_AIX5MP)
 	return( usleep( msecs ) );
 #else
 	struct timeval biteme;
