@@ -1,12 +1,16 @@
 
+static char rcsid[] =
+	"$Id: nmdclass.c,v 1.4 1999/07/08 19:00:04 kohl Exp $";
+
 /*
- *           PVM 3.2:  Parallel Virtual Machine System 3.2
+ *         PVM version 3.4:  Parallel Virtual Machine System
  *               University of Tennessee, Knoxville TN.
  *           Oak Ridge National Laboratory, Oak Ridge TN.
  *                   Emory University, Atlanta GA.
- *      Authors:  A. L. Beguelin, J. J. Dongarra, G. A. Geist,
- *    W. C. Jiang, R. J. Manchek, B. K. Moore, and V. S. Sunderam
- *                   (C) 1992 All Rights Reserved
+ *      Authors:  J. J. Dongarra, G. E. Fagg, M. Fischer
+ *          G. A. Geist, J. A. Kohl, R. J. Manchek, P. Mucci,
+ *         P. M. Papadopoulos, S. L. Scott, and V. S. Sunderam
+ *                   (C) 1997 All Rights Reserved
  *
  *                              NOTICE
  *
@@ -22,8 +26,8 @@
  * purpose.  This software is provided ``as is'' without express or
  * implied warranty.
  *
- * PVM 3.2 was funded in part by the U.S. Department of Energy, the
- * National Science Foundation and the State of Tennessee.
+ * PVM version 3 was funded in part by the U.S. Department of Energy,
+ * the National Science Foundation and the State of Tennessee.
  */
 
 /*
@@ -31,7 +35,24 @@
  *
  *	Name-server database.
  *
-$Log: nmdclass.c,v $
+ * $Log: nmdclass.c,v $
+ * Revision 1.4  1999/07/08 19:00:04  kohl
+ * Fixed "Log" keyword placement.
+ * 	- indent with " * " for new CVS.
+ *
+ * Revision 1.3  1997/06/25  22:09:16  pvmsrc
+ * Markus adds his frigging name to the author list of
+ * 	every file he ever looked at...
+ *
+ * Revision 1.2  1997/01/28  19:26:55  pvmsrc
+ * New Copyright Notice & Authors.
+ *
+ * Revision 1.1  1996/09/23  23:44:22  pvmsrc
+ * Initial revision
+ *
+ * Revision 1.2  1994/06/03  20:38:19  manchek
+ * version 3.3.0
+ *
  * Revision 1.1  1993/08/30  23:26:49  manchek
  * Initial revision
  *
@@ -44,7 +65,7 @@ $Log: nmdclass.c,v $
 #else
 #include <strings.h>
 #endif
-#include "protoglarp.h"
+#include <pvm3.h>
 #include "pvmalloc.h"
 #include "listmac.h"
 
@@ -77,7 +98,6 @@ struct nmdind {
  **           **
  ***************/
 
-static char rcsid[] = "$Id: nmdclass.c,v 1.1 1993/08/30 23:26:49 manchek Exp $";
 static char pvmtxt[1024];				/* scratch for error log */
 static struct nmdcls *classes = 0;		/* the database */
 
