@@ -1,12 +1,16 @@
 
+static char rcsid[] =
+	"$Id: pkt.c,v 1.4 1999/07/08 19:00:05 kohl Exp $";
+
 /*
- *         PVM version 3.3:  Parallel Virtual Machine System
+ *         PVM version 3.4:  Parallel Virtual Machine System
  *               University of Tennessee, Knoxville TN.
  *           Oak Ridge National Laboratory, Oak Ridge TN.
  *                   Emory University, Atlanta GA.
- *      Authors:  A. L. Beguelin, J. J. Dongarra, G. A. Geist,
- *    W. C. Jiang, R. J. Manchek, B. K. Moore, and V. S. Sunderam
- *                   (C) 1992 All Rights Reserved
+ *      Authors:  J. J. Dongarra, G. E. Fagg, M. Fischer
+ *          G. A. Geist, J. A. Kohl, R. J. Manchek, P. Mucci,
+ *         P. M. Papadopoulos, S. L. Scott, and V. S. Sunderam
+ *                   (C) 1997 All Rights Reserved
  *
  *                              NOTICE
  *
@@ -31,7 +35,23 @@
  *
  *	Packet buffers.
  *
-$Log: pkt.c,v $
+ * $Log: pkt.c,v $
+ * Revision 1.4  1999/07/08 19:00:05  kohl
+ * Fixed "Log" keyword placement.
+ * 	- indent with " * " for new CVS.
+ *
+ * Revision 1.3  1997/06/27  17:32:32  pvmsrc
+ * Updated for WIN32 header files & Authors.
+ *
+ * Revision 1.2  1997/01/28  19:26:56  pvmsrc
+ * New Copyright Notice & Authors.
+ *
+ * Revision 1.1  1996/09/23  23:44:23  pvmsrc
+ * Initial revision
+ *
+ * Revision 1.3  1995/07/24  18:27:24  manchek
+ * zero pk_cpos on create
+ *
  * Revision 1.2  1994/06/03  20:38:20  manchek
  * version 3.3.0
  *
@@ -41,8 +61,13 @@ $Log: pkt.c,v $
  */
 
 #include <stdio.h>
+#ifndef WIN32
 #include <sys/time.h>
-#include "protoglarp.h"
+#else
+#include "pvmwin.h"
+#endif
+
+#include <pvm3.h>
 #include "pvmalloc.h"
 #include "pkt.h"
 #include "pvmdabuf.h"
@@ -58,7 +83,6 @@ extern void pvmbailout();
  **           **
  ***************/
 
-static char rcsid[] = "$Id: pkt.c,v 1.2 1994/06/03 20:38:20 manchek Exp $";
 
 
 /*********************
@@ -74,7 +98,7 @@ static char rcsid[] = "$Id: pkt.c,v 1.2 1994/06/03 20:38:20 manchek Exp $";
 *	Else, the pkt has no data (is a master or will get data later).
 *
 *	The following fields are uninitialized:
-*	pk_src, pk_dst, pk_flag, pk_hostd,
+*	pk_src, pk_dst, pk_flag, pk_tag, pk_ctx, pk_enc, pk_wid, pk_crc, pk_hostd,
 *	pk_seq, pk_ack, pk_rtv, pk_rta, pk_rto, pk_at, pk_nrt
 */
 
@@ -103,6 +127,7 @@ pk_new(len)
 		pp->pk_dat = pp->pk_buf = 0;
 		pp->pk_link = pp->pk_rlink = pp;
 	}
+	pp->pk_cpos = 0;
 	pp->pk_tlink = pp->pk_trlink = 0;
 	return pp;
 
