@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: pmsg.c,v 1.13 1999/07/08 19:00:05 kohl Exp $";
+	"$Id: pmsg.c,v 1.17 2001/02/07 23:15:50 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -36,6 +36,27 @@ static char rcsid[] =
  *	Libpvm and pvmd message descriptors
  *
  * $Log: pmsg.c,v $
+ * Revision 1.17  2001/02/07 23:15:50  pvmsrc
+ * 2nd Half of CYGWIN Check-ins...
+ * (Spanker=kohl)
+ *
+ * Revision 1.16  2001/02/06 22:26:57  pvmsrc
+ * Added handling for -DUSE_XDR_LONGLONG.
+ * 	- for Alphas with broken XDR...
+ * (Spanker=kohl)
+ *
+ * Revision 1.15  2000/02/16 21:59:48  pvmsrc
+ * Fixed up #include <sys/types.h> stuff...
+ * 	- use <bsd/sys/types.h> for IMA_TITN...
+ * 	- #include before any NEEDMENDIAN #includes...
+ * (Spanker=kohl)
+ *
+ * Revision 1.14  2000/02/11 20:42:09  pvmsrc
+ * Added support for rare Strongarm float byte order to fbol()...
+ * 	- hope this doesn't break anything else!!!
+ * 	- submitted by Alexander Schulz <un23@rz.uni-karlsruhe.de>.
+ * (Spanker=kohl)
+ *
  * Revision 1.13  1999/07/08 19:00:05  kohl
  * Fixed "Log" keyword placement.
  * 	- indent with " * " for new CVS.
@@ -108,6 +129,7 @@ static char rcsid[] =
 
 #include <stdio.h>
 #ifdef NEEDMENDIAN
+#include <sys/types.h>
 #include <machine/endian.h>
 #endif
 #ifdef NEEDENDIAN
@@ -118,12 +140,10 @@ static char rcsid[] =
 #endif
 
 #include <pvm3.h>
-#ifdef WIN32
-#ifndef _XDR_HEADERS
-#define _XDR_HEADERS
+
+#if defined(WIN32) || defined(CYGWIN)
 #include "..\xdr\types.h"
 #include "..\xdr\xdr.h"
-#endif
 #else
 #include <rpc/types.h>
 #include <rpc/xdr.h>
@@ -194,7 +214,7 @@ ibol(o, p, n)
 
 	j = ffs(n) - 1;
 /*
-	printf(".%d%d.%d%d%d", (i & 2) ? 1 : 0, (i & 1) ? 1 : 0
+	printf(".%d%d.%d%d%d", (i & 2) ? 1 : 0, (i & 1) ? 1 : 0,
 			(j & 4) ? 1 : 0, (j & 2) ? 1 : 0, (j & 1) ? 1 : 0);
 */
 	return ((i << 3) | j) << o;
@@ -272,9 +292,17 @@ fbol(o, p, n)
 					break;
 			if (j == n)
 				return i << o;
+
+			/* weird float byte order for Strongarm?! */
+			/* submitted Alexander Schulz <un23@rz.uni-karlsruhe.de> */
+			for (j = 0; j < n; j++)
+				if (p[(((j/4)*8)+3)-j] != thesigs[i].bytes[j])
+					break;
+			if (j == n)
+				return ((2 << 4) | i) << o;
 		}
 	}
-	fprintf(stderr, "can't generate signature for my integer byte order\n");
+	fprintf(stderr, "can't generate signature for my float byte order\n");
 	abort();
 	return 0;
 }
@@ -853,16 +881,33 @@ enc_xdr_long(mp, vp, cnt, std, siz)
 {
     register long *np;
     register char *cp;
-    char     buf[4];
+    char     buf[8];
     int cc = 0;
 
     for (np = (long *)vp; cnt-- > 0; np += std) {
         cp = (char *)np;
+#ifdef USE_XDR_LONGLONG
+        buf[7] = *cp;
+        buf[6] = *(cp+1);
+        buf[5] = *(cp+2);
+        buf[4] = *(cp+3);
+        buf[3] = *(cp+4);
+        buf[2] = *(cp+5);
+        buf[1] = *(cp+6);
+        buf[0] = *(cp+7);
+#else
         buf[3] = *cp;
         buf[2] = *(cp+1);
         buf[1] = *(cp+2);
         buf[0] = *(cp+3);
-        if (cc = bytepk(mp, buf, 4, 1, 1))
+#endif
+        if (cc = bytepk(mp, buf,
+#ifdef USE_XDR_LONGLONG
+				8,
+#else
+				4,
+#endif
+				1, 1))
             return cc;
     }
     return 0;
@@ -1056,17 +1101,34 @@ dec_xdr_long(mp, vp, cnt, std, siz)
 {
     register long *np;
     register char *cp;
-    char     buf[4];
+    char     buf[8];
     int cc = 0;
 
     for (np = (long *)vp; cnt-- > 0; np += std) {
-        if (cc = byteupk(mp, buf, 4, 1, 1))
+        if (cc = byteupk(mp, buf,
+#ifdef USE_XDR_LONGLONG
+				8,
+#else
+				4,
+#endif
+				1, 1))
             return cc;
         cp = (char *)np;
+#ifdef USE_XDR_LONGLONG
+        *cp     = buf[7];
+        *(cp+1) = buf[6];
+        *(cp+2) = buf[5];
+        *(cp+3) = buf[4];
+        *(cp+4) = buf[3];
+        *(cp+5) = buf[2];
+        *(cp+6) = buf[1];
+        *(cp+7) = buf[0];
+#else
         *cp = buf[3];
         *(cp+1) = buf[2];
         *(cp+2) = buf[1];
         *(cp+3) = buf[0];
+#endif
     }
     return 0;
 }
@@ -1327,9 +1389,21 @@ enc_xdr_long(mp, vp, cnt, std, siz)
 	int cc = 0;
 
 	for (np = (long*)vp; cnt-- > 0; np += std)
-		if (!xdr_long(&mp->m_xdr, np)) {
+#ifdef USE_XDR_LONGLONG
+		if (!xdr_longlong_t(&mp->m_xdr, np))
+#else
+		if (!xdr_long(&mp->m_xdr, np))
+#endif
+		{
+#ifdef USE_XDR_LONGLONG
+			if ((*np & ~(long)0x7fffffffffffffff)
+			&& (*np & ~(long)0x7fffffffffffffff)
+					!= ~(long)0x7fffffffffffffff)
+#else
 			if ((*np & ~(long)0x7fffffff)
-			&& (*np & ~(long)0x7fffffff) != ~(long)0x7fffffff) {
+			&& (*np & ~(long)0x7fffffff) != ~(long)0x7fffffff)
+#endif
+			{
 				cc = PvmOverflow;
 				break;
 			}
@@ -1337,7 +1411,12 @@ enc_xdr_long(mp, vp, cnt, std, siz)
 			if (cc = enc_xdr_step(mp))
 				break;
 			else
-				if (!xdr_long(&mp->m_xdr, np)) {
+#ifdef USE_XDR_LONGLONG
+				if (!xdr_longlong_t(&mp->m_xdr, np))
+#else
+				if (!xdr_long(&mp->m_xdr, np))
+#endif
+				{
 					cc = PvmNoMem;
 					break;
 				}
@@ -1357,8 +1436,18 @@ enc_xdr_ulong(mp, vp, cnt, std, siz)
 	int cc = 0;
 
 	for (np = (unsigned long*)vp; cnt-- > 0; np += std)
-		if (!xdr_u_long(&mp->m_xdr, np)) {
-			if (*np & ~(long)0xffffffff) {
+#ifdef USE_XDR_LONGLONG
+		if (!xdr_u_longlong_t(&mp->m_xdr, np))
+#else
+		if (!xdr_u_long(&mp->m_xdr, np))
+#endif
+		{
+#ifdef USE_XDR_LONGLONG
+			if (*np & ~(long)0xffffffffffffffff)
+#else
+			if (*np & ~(long)0xffffffff)
+#endif
+			{
 				cc = PvmOverflow;
 				break;
 			}
@@ -1366,7 +1455,12 @@ enc_xdr_ulong(mp, vp, cnt, std, siz)
 			if (cc = enc_xdr_step(mp))
 				break;
 			else
-				if (!xdr_u_long(&mp->m_xdr, np)) {
+#ifdef USE_XDR_LONGLONG
+				if (!xdr_u_longlong_t(&mp->m_xdr, np))
+#else
+				if (!xdr_u_long(&mp->m_xdr, np))
+#endif
+				{
 					cc = PvmNoMem;
 					break;
 				}
@@ -1560,9 +1654,10 @@ dec_xdr_step(mp)
 			return PvmBadMsg;
 
 		} else {
-/*
-			pvmlogprintf("fragment has %d bytes left, doing fixup\n", l);
-*/
+			/*
+			pvmlogprintf("fragment has %d bytes left, doing fixup\n",
+					l);
+			*/
 			fp->fr_dat -= l;
 			fp->fr_len += l;
 			BCOPY(p, fp->fr_dat, l);
@@ -1662,12 +1757,22 @@ dec_xdr_long(mp, vp, cnt, std, siz)
 	int cc = 0;
 
 	for (np = (long*)vp; cnt-- > 0; np += std)
-		if (!xdr_long(&mp->m_xdr, np)) {
+#ifdef USE_XDR_LONGLONG
+		if (!xdr_longlong_t(&mp->m_xdr, np))
+#else
+		if (!xdr_long(&mp->m_xdr, np))
+#endif
+		{
 			mp->m_cpos = xdr_getpos(&mp->m_xdr);
 			if (cc = dec_xdr_step(mp))
 				break;
 			else
-				if (!xdr_long(&mp->m_xdr, np)) {
+#ifdef USE_XDR_LONGLONG
+				if (!xdr_longlong_t(&mp->m_xdr, np))
+#else
+				if (!xdr_long(&mp->m_xdr, np))
+#endif
+				{
 					cc = PvmNoData;
 					break;
 				}
@@ -1737,12 +1842,22 @@ dec_xdr_ulong(mp, vp, cnt, std, siz)
 	int cc = 0;
 
 	for (np = (unsigned long*)vp; cnt-- > 0; np += std)
-		if (!xdr_u_long(&mp->m_xdr, np)) {
+#ifdef USE_XDR_LONGLONG
+		if (!xdr_u_longlong_t(&mp->m_xdr, np))
+#else
+		if (!xdr_u_long(&mp->m_xdr, np))
+#endif
+		{
 			mp->m_cpos = xdr_getpos(&mp->m_xdr);
 			if (cc = dec_xdr_step(mp))
 				break;
 			else
-				if (!xdr_u_long(&mp->m_xdr, np)) {
+#ifdef USE_XDR_LONGLONG
+				if (!xdr_u_longlong_t(&mp->m_xdr, np))
+#else
+				if (!xdr_u_long(&mp->m_xdr, np))
+#endif
+				{
 					cc = PvmNoData;
 					break;
 				}
