@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: pvmcruft.c,v 1.40 2004/03/10 17:01:27 pvmsrc Exp $";
+	"$Id: pvmcruft.c,v 1.42 2005/08/22 15:13:20 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -36,6 +36,16 @@ static char rcsid[] =
  *	Missing links and other wonk.
  *
  * $Log: pvmcruft.c,v $
+ * Revision 1.42  2005/08/22 15:13:20  pvmsrc
+ * Added #include <pvmtev.h> for #include global.h...  :-Q
+ * 	- submitted by Skipper Hartley <charles.l.hartley@bankofamerica.com>
+ * (Spanker=kohl)
+ *
+ * Revision 1.41  2005/05/18 17:55:55  pvmsrc
+ * Added new pvmchkuid() routine...
+ * 	- make sure PVM isn't run as root!  :-o
+ * (Spanker=kohl)
+ *
  * Revision 1.40  2004/03/10 17:01:27  pvmsrc
  * Fixed funny pvmtmpnam() bug...  (ha ha ha :)
  * 	- first pvmd call for socket file will name clash after 10000
@@ -293,6 +303,7 @@ static char rcsid[] =
 #include <pvmproto.h>
 #include "pvmalloc.h"
 #include "lpvm.h"
+#include <pvmtev.h>
 #include "global.h"
 
 #ifdef WIN32
@@ -452,13 +463,13 @@ extern char **environ;
 #endif
 
 /*	pvmputenv()
-*
-*	Replacement for systems that don't have putenv.
-*	Tries to be conservative, i.e. doesn't assume that environ
-*	points to malloc'd space.
-*
-*	String must never be freed...
-*/
+ *
+ *	Replacement for systems that don't have putenv.
+ *	Tries to be conservative, i.e. doesn't assume that environ
+ *	points to malloc'd space.
+ *
+ *	String must never be freed...
+ */
 
 int
 pvmputenv(s)
@@ -513,13 +524,13 @@ pvmputenv(s)
 
 
 /*	pvmcopyenv()
-*
-*	Make copy of an environment list (null-terminated vector of strings).
-*	This is just like environ, but we own all the strings.
-*	Can also be used to create an empty list, by passing a null pointer.
-*
-*	Returns pointer to environment or NULL if malloc fails.
-*/
+ *
+ *	Copy an environment list (null-terminated vector of strings).
+ *	This is just like environ, but we own all the strings.
+ *	Can also be used to create an empty list, by passing a null pointer.
+ *
+ *	Returns pointer to environment or NULL if malloc fails.
+ */
 
 char **
 pvmcopyenv(anyep)
@@ -552,13 +563,13 @@ pvmcopyenv(anyep)
 
 
 /*	pvmenvinsert()
-*
-*	Put a copy of a string into an environment list (made by pvmcopyenv).
-*	List must be one of ours, since we malloc and free the strings.
-*
-*	Returns zero or success, or -1 if malloc fails.
-*	May update pointer to environment on return.
-*/
+ *
+ *	Copy a string into an environment list (made by pvmcopyenv).
+ *	List must be one of ours, since we malloc and free the strings.
+ *
+ *	Returns zero or success, or -1 if malloc fails.
+ *	May update pointer to environment on return.
+ */
 
 int
 pvmenvinsert(anep, s)
@@ -604,9 +615,9 @@ pvmenvinsert(anep, s)
 
 
 /*	pvmfreeenv()
-*
-*	Free an environment list (made by pvmcopyenv).
-*/
+ *
+ *	Free an environment list (made by pvmcopyenv).
+ */
 
 int
 pvmfreeenv(anep)
@@ -622,9 +633,9 @@ pvmfreeenv(anep)
 
 
 /*	pvmxtoi()
-*
-*	Yet another version of ascii hex to integer
-*/
+ *
+ *	Yet another version of ascii hex to integer
+ */
 
 pvmxtoi(p)
 	char *p;
@@ -642,9 +653,9 @@ pvmxtoi(p)
 
 
 /*	pvmstrtoi()
-*
-*	Convert string in decimal, hex or octal to integer.
-*/
+ *
+ *	Convert string in decimal, hex or octal to integer.
+ */
 
 int
 pvmstrtoi(p)
@@ -671,9 +682,9 @@ pvmstrtoi(p)
 #ifndef	I860_NODE
 
 /*	hex_inadport()
-*
-*	Takes a string of format 00000000:0000 and returns a sockaddr_in.
-*/
+ *
+ *	Takes a string of format 00000000:0000 and returns a sockaddr_in.
+ */
 
 void
 hex_inadport(s, sad)
@@ -687,9 +698,9 @@ hex_inadport(s, sad)
 
 
 /*	inadport_decimal()
-*
-*	Returns printable string corr. to sockaddr_in with addr in decimal.
-*/
+ *
+ *	Returns printable string corr. to sockaddr_in with addr in decimal.
+ */
 
 char *
 inadport_decimal(sad)
@@ -710,9 +721,9 @@ inadport_decimal(sad)
 
 
 /*	inadport_hex()
-*
-*	Returns printable string corr. to sockaddr_in with addr in hex.
-*/
+ *
+ *	Returns printable string corr. to sockaddr_in with addr in hex.
+ */
 
 char *
 inadport_hex(sad)
@@ -835,9 +846,9 @@ pvmhdump(cp, n, pad)
 
 
 /*	pvmgethome()
-*
-*	Return path of user homedir.
-*/
+ *
+ *	Return path of user homedir.
+ */
 
 char *
 pvmgethome()
@@ -861,9 +872,9 @@ pvmgethome()
 
 
 /*	pvmgetroot()
-*
-*	Return absolute path of PVM top level directory.
-*/
+ *
+ *	Return absolute path of PVM top level directory.
+ */
 
 char *
 pvmgetroot()
@@ -913,9 +924,9 @@ pvmgetroot()
 
 
 /*	pvmgettmp()
-*
-*	Return absolute path of PVM temporary directory.
-*/
+ *
+ *	Return absolute path of PVM temporary directory.
+ */
 
 char *
 pvmgettmp()
@@ -951,9 +962,9 @@ pvmgettmp()
 
 
 /*	pvmgetrsh()
-*
-*	Return absolute path of the rsh executable for the local system.
-*/
+ *
+ *	Return absolute path of the rsh executable for the local system.
+ */
 
 char *
 pvmgetrsh()
@@ -970,9 +981,9 @@ pvmgetrsh()
 
 
 /*	pvmgetpvmd()
-*
-*	Return absolute path of pvmd startup script.
-*/
+ *
+ *	Return absolute path of pvmd startup script.
+ */
 
 char *
 pvmgetpvmd()
@@ -994,10 +1005,10 @@ pvmgetpvmd()
 
 
 /*	pvmdsockfile()
-*
-*	Returns name of file where pvmd advertises its sockaddr.
-*	Assumes global pvm_useruid is set before calling.
-*/
+ *
+ *	Returns name of file where pvmd advertises its sockaddr.
+ *	Assumes global pvm_useruid is set before calling.
+ */
 
 char *
 pvmdsockfile()
@@ -1060,10 +1071,10 @@ pvmdsockfile()
 #include <sys/cnx_pattr.h>
 
 /*	get_scid ()
-*
-*	(Convex CSPP only)
-*	Returns the subcomplex identifier for the calling process
-*/
+ *
+ *	(Convex CSPP only)
+ *	Returns the subcomplex identifier for the calling process
+ */
 
 int
 get_scid ()
@@ -1212,11 +1223,11 @@ static struct nametag nametaglist[] = {
 
 
 /*	pvmnametag()
-*
-*	Convert message tag to symbolic name for reserved tags.
-*	Returns name string or decimal tag if not found.
-*	If found is nonnull, return whether found.
-*/
+ *
+ *	Convert message tag to symbolic name for reserved tags.
+ *	Returns name string or decimal tag if not found.
+ *	If found is nonnull, return whether found.
+ */
 
 char *
 pvmnametag(tag, found)
@@ -1242,9 +1253,9 @@ pvmnametag(tag, found)
 
 
 /*	debug_flags()
-*
-*	Convert debug mask to flag names
-*/
+ *
+ *	Convert debug mask to flag names
+ */
 
 static char *dflgs[] = {
 	"pkt",	/* 1 */
@@ -1284,9 +1295,9 @@ debug_flags(mask)
 
 
 /*	print_fdset()
-*
-*	Print an fd_set in human-readable format.
-*/
+ *
+ *	Print an fd_set in human-readable format.
+ */
 
 print_fdset(pad, n, f)
 	char *pad;			/* label at head */
@@ -1328,11 +1339,11 @@ gettimeofday(tp, tzp)
 
 
 /*	pvmgetclock()
-*
-*	Use this whenever we need a clock value in seconds and microseconds.
-*	Return values shouldn't be compared to those from gettimeofday,
-*	because it doesn't necessarily return the actual time of day.
-*/
+ *
+ *	Use this whenever we need a clock value in seconds and microseconds.
+ *	Return values shouldn't be compared to those from gettimeofday,
+ *	because it doesn't necessarily return the actual time of day.
+ */
 
 int
 pvmgetclock(tm)
@@ -1352,10 +1363,10 @@ pvmgetclock(tm)
 
 
 /*  pvmsleep()
-*
-*   A consistent way to invoke sleep(), from:
-*     Unix / Windows, C / Fortran
-*/
+ *
+ *   A consistent way to invoke sleep(), from:
+ *     Unix / Windows, C / Fortran
+ */
 
 int
 pvmsleep( secs )
@@ -1373,9 +1384,9 @@ int secs;
 
 
 /*	pvmmatchstring()
-*
-*	Replacement for GNU Regex pattern matching.
-*/
+ *
+ *	Replacement for GNU Regex pattern matching.
+ */
 
 int
 pvmmatchstring( str, pattern )
@@ -1460,3 +1471,56 @@ char *pattern;
 	return( 0 );
 }
 
+/* pvmchkuid()
+ *
+ * Verify that PVM isn't running as user "root"...!
+ * 
+ * This often creates all sorts of havoc for first-time PVM
+ * users, so give them a big fat warning message and bail out...
+ * (If they *really* need to run as root, force them to set
+ * the $PVM_ALLOW_ROOT environment variable...  this will
+ * "root" out the novice users...  tee-hee... :-)
+ */
+
+void
+pvmchkuid( uid )
+int uid;
+{
+	char *p;
+
+	/* We are Running as User "root" - Bad Baby, Bad Baby...! :-o */
+	if ( !uid )
+	{
+		/* Let the Brave User Shoot Self in Foot... :-) */
+		if ( (p = getenv( "PVM_ALLOW_ROOT" )) != NULL )
+			return;
+
+		printf( "\n" );
+		printf( "*** Error: PVM is being run as user \"root\" ***!\n" );
+		printf( "\n" );
+		printf( "This is not a good idea, and often doesn't work!\n" );
+		printf( "\n" );
+		printf( "The root user cannot typically rsh/ssh to remote\n" );
+		printf( "computers over the network, to add them as hosts\n" );
+		printf( "to the PVM virtual machine.\n" );
+		printf( "\n" );
+		printf( "You can install PVM in a system-wide directory,\n" );
+		printf( "with the files *owned* by user \"root\",\n" );
+		printf( "but you need to *run* PVM as a *regular* user!\n" );
+		printf( "\n" );
+		printf( "\n" );
+		printf( "*If* you know what you're doing, and you are\n" );
+		printf( "willing to accept the security risks, then you\n" );
+		printf( "can enable root execution of PVM by setting the\n" );
+		printf( "%s environment variable in your shell.\n",
+				"PVM_ALLOW_ROOT" );
+		printf( "\n" );
+		printf( "Please send any inquiries regarding this feature\n" );
+		printf( "to:  pvm@csm.msr.ornl.gov\n" );
+		printf( "\n" );
+
+		pvmbailout(0);
+		exit(1);		/* the other meaning of bail out */
+	}
+}
+
