@@ -1,12 +1,16 @@
 
+static char rcsid[] =
+	"$Id: pvmdabuf.c,v 1.5 1999/07/08 19:00:10 kohl Exp $";
+
 /*
- *           PVM 3.2:  Parallel Virtual Machine System 3.2
+ *         PVM version 3.4:  Parallel Virtual Machine System
  *               University of Tennessee, Knoxville TN.
  *           Oak Ridge National Laboratory, Oak Ridge TN.
  *                   Emory University, Atlanta GA.
- *      Authors:  A. L. Beguelin, J. J. Dongarra, G. A. Geist,
- *    W. C. Jiang, R. J. Manchek, B. K. Moore, and V. S. Sunderam
- *                   (C) 1992 All Rights Reserved
+ *      Authors:  J. J. Dongarra, G. E. Fagg, M. Fischer
+ *          G. A. Geist, J. A. Kohl, R. J. Manchek, P. Mucci,
+ *         P. M. Papadopoulos, S. L. Scott, and V. S. Sunderam
+ *                   (C) 1997 All Rights Reserved
  *
  *                              NOTICE
  *
@@ -22,8 +26,8 @@
  * purpose.  This software is provided ``as is'' without express or
  * implied warranty.
  *
- * PVM 3.2 was funded in part by the U.S. Department of Energy, the
- * National Science Foundation and the State of Tennessee.
+ * PVM version 3 was funded in part by the U.S. Department of Energy,
+ * the National Science Foundation and the State of Tennessee.
  */
 
 /*
@@ -31,23 +35,50 @@
  *
  *	Data buffer manip.
  *
-$Log: pvmdabuf.c,v $
+ * $Log: pvmdabuf.c,v $
+ * Revision 1.5  1999/07/08 19:00:10  kohl
+ * Fixed "Log" keyword placement.
+ * 	- indent with " * " for new CVS.
+ *
+ * Revision 1.4  1997/06/25  22:09:20  pvmsrc
+ * Markus adds his frigging name to the author list of
+ * 	every file he ever looked at...
+ *
+ * Revision 1.3  1997/03/06  21:10:17  pvmsrc
+ * 	quad align dabufs by adding double q[2] in alignme
+ *
+ * Revision 1.2  1997/01/28  19:27:04  pvmsrc
+ * New Copyright Notice & Authors.
+ *
+ * Revision 1.1  1996/09/23  23:44:31  pvmsrc
+ * Initial revision
+ *
+ * Revision 1.2  1994/06/03  20:38:23  manchek
+ * version 3.3.0
+ *
  * Revision 1.1  1993/08/30  23:26:50  manchek
  * Initial revision
  *
  */
 
-#include "protoglarp.h"
+#include <pvm3.h>
 #include "pvmalloc.h"
 
+union alignme {
+	long l;
+	char *p;
+	double d;
+	double q[2];		/* quad-word alignment */
+};
+
+#define	RCOFFSET	sizeof(union alignme)
+
 
 /***************
  **  Private  **
  **           **
  ***************/
 
-static char rcsid[] = "$Id: pvmdabuf.c,v 1.1 1993/08/30 23:26:50 manchek Exp $";
-
 
 char *
 da_new(len)
@@ -55,8 +86,8 @@ da_new(len)
 {
 	char *p;
 
-	if (p = TALLOC(len + 16, char, "data")) {
-		p += 16;
+	if (p = TALLOC(len + RCOFFSET, char, "data")) {
+		p += RCOFFSET;
 		*(int*)(p - sizeof(int)) = 1;
 	}
 	return p;
@@ -76,7 +107,7 @@ da_unref(p)
 	char *p;
 {
 	if (--*(int*)(p - sizeof(int)) < 1)
-		PVM_FREE(p - 16);
+		PVM_FREE(p - RCOFFSET);
 }
 
 
