@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: pvmdpack.c,v 1.11 2001/02/07 23:15:53 pvmsrc Exp $";
+	"$Id: pvmdpack.c,v 1.12 2005/08/22 15:13:20 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -36,6 +36,11 @@ static char rcsid[] =
  *	Pvmd message packing and unpacking.
  *
  * $Log: pvmdpack.c,v $
+ * Revision 1.12  2005/08/22 15:13:20  pvmsrc
+ * Added #include <pvmtev.h> for #include global.h...  :-Q
+ * 	- submitted by Skipper Hartley <charles.l.hartley@bankofamerica.com>
+ * (Spanker=kohl)
+ *
  * Revision 1.11  2001/02/07 23:15:53  pvmsrc
  * 2nd Half of CYGWIN Check-ins...
  * (Spanker=kohl)
@@ -114,6 +119,7 @@ static char rcsid[] =
 #include "pvmfrag.h"
 #include "pmsg.h"
 #include "listmac.h"
+#include <pvmtev.h>
 #include "global.h"
 
 
