@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: pvmdshmem.c,v 1.21 2004/01/14 18:51:02 pvmsrc Exp $";
+	"$Id: pvmdshmem.c,v 1.23 2009/01/30 21:22:46 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -36,6 +36,16 @@ static char rcsid[] =
  * Shared-memory MPP interface.
  *
  * $Log: pvmdshmem.c,v $
+ * Revision 1.23  2009/01/30 21:22:46  pvmsrc
+ * Fixed up insecure usage of fopen() for creating/writing/appending files.
+ * 	- replace with open(...O_EXCL...) and fdopen()...
+ * (Spanker=kohl)
+ *
+ * Revision 1.22  2005/08/22 15:13:21  pvmsrc
+ * Added #include <pvmtev.h> for #include global.h...  :-Q
+ * 	- submitted by Skipper Hartley <charles.l.hartley@bankofamerica.com>
+ * (Spanker=kohl)
+ *
  * Revision 1.21  2004/01/14 18:51:02  pvmsrc
  * Added new AIX5* arches.
  * (Spanker=kohl)
@@ -217,6 +227,7 @@ static char rcsid[] =
 #include <sys/param.h>
 #include <sys/types.h>
 #include <sys/time.h>
+#include <sys/stat.h>
 #include <netinet/in.h>
 #include <fcntl.h>
 #ifdef IMA_SYMM
@@ -248,6 +259,7 @@ static char rcsid[] =
 #include "bfunc.h"
 #include "host.h"
 #include "waitc.h"
+#include <pvmtev.h>
 #include "global.h"
 
 #ifndef max
@@ -357,6 +369,7 @@ ppi_init()
 	char *pvmtmp = pvmgettmp();
 	char *p;
 	int key;
+	int fd;
 
 #ifdef LOG
 	char fname[32];
@@ -369,7 +382,9 @@ ppi_init()
 #else
 	sprintf(fname, "%s/pvmt.%d", pvmtmp, pvm_useruid);
 #endif
-	logfp = fopen(fname, "w");
+	if ((fd = open( fname, O_RDWR|O_CREAT|O_EXCL|O_TRUNC, 0600 )) < 0) {
+	}
+	logfp = fdopen( fd, "w" );
 	fclose(logfp);
 #endif	/*LOG*/
 
