@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: pvmshmem.c,v 1.11 2004/01/14 18:51:03 pvmsrc Exp $";
+	"$Id: pvmshmem.c,v 1.12 2005/08/22 15:13:25 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -36,6 +36,11 @@ static char rcsid[] =
  *  Shared-memory stuff.
  *
  * $Log: pvmshmem.c,v $
+ * Revision 1.12  2005/08/22 15:13:25  pvmsrc
+ * Added #include <pvmtev.h> for #include global.h...  :-Q
+ * 	- submitted by Skipper Hartley <charles.l.hartley@bankofamerica.com>
+ * (Spanker=kohl)
+ *
  * Revision 1.11  2004/01/14 18:51:03  pvmsrc
  * Added new AIX5* arches.
  * (Spanker=kohl)
@@ -179,6 +184,7 @@ static char rcsid[] =
 #include "pvmshmem.h"
 #include "bfunc.h"
 
+#include <pvmtev.h>
 #include "global.h"
 
 #ifndef min
