@@ -1,5 +1,5 @@
 
-/* $Id: pvmshmem.h,v 1.7 1999/07/08 19:00:24 kohl Exp $ */
+/* $Id: pvmshmem.h,v 1.9 2004/01/14 18:51:03 pvmsrc Exp $ */
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -33,6 +33,15 @@
  *  pvmshmem.h
  *
  * $Log: pvmshmem.h,v $
+ * Revision 1.9  2004/01/14 18:51:03  pvmsrc
+ * Added new AIX5* arches.
+ * (Spanker=kohl)
+ *
+ * Revision 1.8  2000/02/10 20:45:49  pvmsrc
+ * Replaced hard-coded /tmp usage with PVMSHMFILE.
+ * 	- use pvmgettmp() routine now to determine PVM temp dir.
+ * (Spanker=kohl)
+ *
  * Revision 1.7  1999/07/08 19:00:24  kohl
  * Fixed "Log" keyword placement.
  * 	- indent with " * " for new CVS.
@@ -167,7 +176,7 @@ struct msgboxhdr {
 #define PAGEUNLOCK(lp)		msem_unlock((lp), 0)
 #endif /*IMA_ALPHAMP*/
 
-#if defined (IMA_RS6KMP) || (IMA_AIX4MP)
+#if defined(IMA_RS6KMP) || defined(IMA_AIX4MP) || defined(IMA_AIX5MP)
 
 #include <pthread.h>
 
@@ -191,7 +200,7 @@ struct msgboxhdr {
 #define PAGELOCK(lp)		pthread_mutex_lock(lp)
 #define PAGEUNLOCK(lp)		pthread_mutex_unlock(lp)
 
-#endif /*IMA_RS6KMP and AIX4MP */
+#endif /*IMA_RS6KMP and AIX4MP and AIX5MP */
 
 #ifdef IMA_SUNMP
 #include <synch.h>
@@ -389,7 +398,7 @@ struct peer {
 #define INBOXPAGE	5			/* size of incoming box (number of pages) */
 #define PERMS		0600		/* permissions for shared-memory msg buffers */
 #define	BUSYWAIT	1000000		/* max wait cycles before backing off */
-#define PVMSHMFILE	"/tmp/pvmshm.%d"	/* file to map to shared memory */
+#define PVMSHMFILE	"%s/pvmshm.%d"	/* file to map to shared memory */
 
 struct peer *peer_conn __ProtoGlarp__((int tid, int *new_connection));
 void peer_init __ProtoGlarp__((void));
