@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: sdpro.c,v 1.7 1999/07/08 19:00:15 kohl Exp $";
+	"$Id: sdpro.c,v 1.12 2007/07/09 19:59:55 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -36,6 +36,31 @@ static char rcsid[] =
  *	Pvmd entry points for messages from scheduler.
  *
  * $Log: sdpro.c,v $
+ * Revision 1.12  2007/07/09 19:59:55  pvmsrc
+ * Added missing "char *pvmnametag();" function decl.
+ * 	- submitted by David Mathog <mathog@caltech.edu>.
+ * (Spanker=kohl)
+ *
+ * Revision 1.11  2005/08/22 15:13:25  pvmsrc
+ * Added #include <pvmtev.h> for #include global.h...  :-Q
+ * 	- submitted by Skipper Hartley <charles.l.hartley@bankofamerica.com>
+ * (Spanker=kohl)
+ *
+ * Revision 1.10  2002/04/16 15:06:04  pvmsrc
+ * WIN32 Fixes for Multiple Domains.
+ * 	- submitted by Jigen Zhou <jigen@icemcfd.com>.
+ * (Spanker=kohl)
+ *
+ * Revision 1.9  2001/02/07 23:15:54  pvmsrc
+ * 2nd Half of CYGWIN Check-ins...
+ * (Spanker=kohl)
+ *
+ * Revision 1.8  2000/02/16 22:00:29  pvmsrc
+ * Fixed up #include <sys/types.h> stuff...
+ * 	- use <bsd/sys/types.h> for IMA_TITN...
+ * 	- #include before any NEEDMENDIAN #includes...
+ * (Spanker=kohl)
+ *
  * Revision 1.7  1999/07/08 19:00:15  kohl
  * Fixed "Log" keyword placement.
  * 	- indent with " * " for new CVS.
@@ -82,6 +107,12 @@ static char rcsid[] =
  */
 
 
+#ifdef IMA_TITN
+#include <bsd/sys/types.h>
+#else
+#include <sys/types.h>
+#endif
+
 #ifdef NEEDMENDIAN
 #include <machine/endian.h>
 #endif
@@ -94,21 +125,24 @@ static char rcsid[] =
 
 #ifdef WIN32
 #include "pvmwin.h"
-#include <time.h>
-#ifndef _XDR_HEADERS
-#define _XDR_HEADERS
+#endif
+
+#if defined(WIN32) || defined(CYGWIN)
 #include "..\xdr\types.h"
 #include "..\xdr\xdr.h"
-#endif
 #else
 #include <rpc/types.h>
 #include <rpc/xdr.h>
+#endif
+
+#ifdef WIN32
+#include <time.h>
+#else
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <sys/time.h>
 #endif
 
-#include <sys/types.h>
 #include <stdio.h>
 
 #include <pvm3.h>
@@ -119,6 +153,7 @@ static char rcsid[] =
 #include "waitc.h"
 #include "task.h"
 #include "bfunc.h"
+#include <pvmtev.h>
 #include "global.h"
 
 
@@ -129,6 +164,9 @@ extern int pvmschedtid;				/* from pvmd.c */
 extern int taskertid;				/* from pvmd.c */
 
 
+char *pvmnametag();
+
+
 /***************
  **  Private  **
  **           **
