@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: task.c,v 1.19 1999/07/08 19:00:15 kohl Exp $";
+	"$Id: task.c,v 1.25 2002/04/16 15:04:50 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -36,6 +36,52 @@ static char rcsid[] =
  *	Task descriptors.
  *
  * $Log: task.c,v $
+ * Revision 1.25  2002/04/16 15:04:50  pvmsrc
+ * Fixed bug in task_cleanup():
+ * 	- & vs && in scheduler notification code...  :-Q
+ * 	- bug report submitted by Yan Xiao <yxiao@BlackstoneComputing.com>.
+ * (Spanker=kohl)
+ *
+ * Revision 1.24  2002/02/21 23:18:07  pvmsrc
+ * Added new (not to be documented!) PVM_MAX_TASKS env var support.
+ * 	- for Mahir Lokvancic <mahir@math.ufl.edu>.
+ * 	- forcefully limits the number of tasks that can attach to a
+ * 		pvmd, required on Solaris in rare circumstances when hard
+ * 		FD_SETSIZE limit is reached, and all hell breaks loose...
+ * 	- check pvm_max_ntasks global when allocating new tasks
+ * 		(0 = no limit)
+ * 	- in task_new() call, if limit reached return NULL ptr,
+ * 		indicating PvmOutOfRes...
+ * 	- keep track of private "ntasks" counter in task_new()/task_free(),
+ * 		only increment for non-zero tids (avoid counting temp task
+ * 		structs...).
+ * (Spanker=kohl)
+ *
+ * Revision 1.23  2001/02/07 23:15:54  pvmsrc
+ * 2nd Half of CYGWIN Check-ins...
+ * (Spanker=kohl)
+ *
+ * Revision 1.22  2000/09/01 14:39:22  pvmsrc
+ * Plugged memory (waitc) leak in task_cleanup():
+ * 	- better get rid of any notify wait contexts, if the task is
+ * 		dead we probably don't care any more...
+ * 	- added wait_delete() for WT_HOSTA, WT_TASKX, WT_ROUTEA, WT_ROUTED.
+ * 	- I hope this doesn't break any shit...  :-o
+ * (Spanker=kohl)
+ *
+ * Revision 1.21  2000/02/17 23:12:19  pvmsrc
+ * *** Changes for new BEOLIN port ***
+ * 	- MPP-like, similar to SP2, etc.
+ * 	- submitted by Paul Springer <pls@smokeymt.jpl.nasa.gov>.
+ * 	- format-checked & cleaned up by Jeembo...  :-)
+ * (Spanker=kohl)
+ *
+ * Revision 1.20  2000/02/16 22:00:30  pvmsrc
+ * Fixed up #include <sys/types.h> stuff...
+ * 	- use <bsd/sys/types.h> for IMA_TITN...
+ * 	- #include before any NEEDMENDIAN #includes...
+ * (Spanker=kohl)
+ *
  * Revision 1.19  1999/07/08 19:00:15  kohl
  * Fixed "Log" keyword placement.
  * 	- indent with " * " for new CVS.
@@ -163,6 +209,12 @@ static char rcsid[] =
  *
  */
 
+#ifdef IMA_TITN
+#include <bsd/sys/types.h>
+#else
+#include <sys/types.h>
+#endif
+
 #ifdef NEEDMENDIAN
 #include <machine/endian.h>
 #endif
@@ -174,24 +226,24 @@ static char rcsid[] =
 #endif
 
 #include <pvm3.h>
-#ifdef WIN32
-#include "pvmwin.h"
-#include <time.h>
-#ifndef _XDR_HEADERS
-#define _XDR_HEADERS
+
+#if defined(WIN32) || defined(CYGWIN)
 #include "..\xdr\types.h"
 #include "..\xdr\xdr.h"
-#endif
 #else
 #include <rpc/types.h>
 #include <rpc/xdr.h>
+#endif
+
+#ifdef WIN32
+#include "pvmwin.h"
+#include <time.h>
+#else
 #include <sys/time.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #endif
 
-#include <sys/types.h>
-
 #ifdef	SYSVSTR
 #include <string.h>
 #else
@@ -227,6 +279,7 @@ extern int myhostpart;				/* from pvmd.c */
 extern int taskertid;				/* from pvmd.c */
 extern struct Pvmtracer pvmtracer;	/* from pvmd.c */
 extern int tidlmask;				/* from pvmd.c */
+extern int pvm_max_ntasks;			/* from pvmd.c */
 
 struct task *locltasks = 0;			/* all task structs sorted by tid */
 
@@ -240,6 +293,8 @@ void tev_send_endtask();
 
 static struct ccon *cconlist = 0;
 
+static int ntasks = 0;	/* tot # of tasks registered w/this pvmd */
+
 
 /*****************
  **  Interface  **
@@ -387,6 +442,19 @@ task_new(tid)
 {
 	struct task *tp, *tp2;
 
+	if (tid) {
+		ntasks++;
+		if (pvmdebmask & PDMTASK) {
+			pvmlogprintf("task_new(%d) ntasks=%d pvm_max_ntasks=%d\n",
+				tid, ntasks, pvm_max_ntasks );
+		}
+		if (pvm_max_ntasks && ntasks > pvm_max_ntasks) {
+			pvmlogprintf("task_new() too many tasks?\n");
+			ntasks--;  /* this one didn't make it... :-) */
+			return( (struct task *) NULL );
+		}
+	}
+
 	if (!(tp = TALLOC(1, struct task, "task"))) {
 		pvmlogprintf("task_new() can't get memory\n");
 		pvmbailout(0);
@@ -432,8 +500,12 @@ task_free(tp)
 #ifdef SHMEM
 	/* XXX this is inside out - mpp_free should call task_free.
 	   XXX but for now task_free is what's called.
-	   XXX this will change in the portable processor interface cleanup. */
+	   XXX this will change in the portable processor interface
+	   XXX cleanup. */
 	mpp_free(tp->t_tid);
+#endif
+#ifdef IMA_BEOLIN
+	mpp_free(tp);
 #endif
 	if (tp->t_plink && tp->t_prlink) {
 		LISTDELETE(tp, t_plink, t_prlink);
@@ -500,6 +572,15 @@ task_free(tp)
 		}
 		PVM_FREE(tp->t_ccs);
 	}
+
+	if (tp->t_tid) {
+		ntasks--;
+		if (pvmdebmask & PDMTASK) {
+			pvmlogprintf("task_free(%d) ntasks=%d\n",
+					tp->t_tid, ntasks );
+		}
+	}
+
 	PVM_FREE(tp);
 }
 
@@ -673,6 +754,10 @@ task_cleanup(tp)
 				switch (wp->wa_kind) {
 
 				case WT_HOSTF:
+				case WT_HOSTA:
+				case WT_TASKX:
+				case WT_ROUTEA:
+				case WT_ROUTED:
 				case WT_TASKSTART:
 					wp2 = wp;				/* some kinds we can toss now */
 					wp = wp->wa_rlink;
@@ -688,7 +773,7 @@ task_cleanup(tp)
 
 		/* notify the scheduler */
 
-		if ((tp->t_sched)&(tp->t_schedlmsg!=SM_TASKX)) {
+		if ((tp->t_sched)&&(tp->t_schedlmsg!=SM_TASKX)) {
 			mp = mesg_new(0);
 			mp->m_dst = tp->t_sched;
 			mp->m_tag = SM_TASKX;
