@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: tdpro.c,v 1.34 2002/02/21 23:18:42 pvmsrc Exp $";
+	"$Id: tdpro.c,v 1.37 2009/01/30 21:22:58 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -36,6 +36,22 @@ static char rcsid[] =
  *	Entry points for messages from local tasks.
  *
  * $Log: tdpro.c,v $
+ * Revision 1.37  2009/01/30 21:22:58  pvmsrc
+ * Fixed up insecure usage of fopen() for creating/writing/appending files.
+ * 	- replace with open(...O_EXCL...) and fdopen()...
+ * Make sure to always return a failure response to connect-attempting tasks.
+ * 	- especially if they fail...  :-}
+ * (Spanker=kohl)
+ *
+ * Revision 1.36  2009/01/23 00:09:34  pvmsrc
+ * Updated BEOLIN changes from Paul Springer...
+ * (Spanker=kohl)
+ *
+ * Revision 1.35  2007/07/09 19:59:55  pvmsrc
+ * Added missing "char *pvmnametag();" function decl.
+ * 	- submitted by David Mathog <mathog@caltech.edu>.
+ * (Spanker=kohl)
+ *
  * Revision 1.34  2002/02/21 23:18:42  pvmsrc
  * Added new (not to be documented!) PVM_MAX_TASKS env var support.
  * 	- for Mahir Lokvancic <mahir@math.ufl.edu>.
@@ -277,6 +293,9 @@ static char rcsid[] =
 #include <sys/types.h>
 #endif
 
+#include <sys/stat.h>
+#include <fcntl.h>
+
 #ifdef NEEDMENDIAN
 #include <machine/endian.h>
 #endif
@@ -325,6 +344,7 @@ static char rcsid[] =
 #include "global.h"
 #ifdef IMA_BEOLIN
 #include "pvmdmp.h"
+#include "pvmmimd.h"
 #endif
 
 #ifndef	min
@@ -340,6 +360,7 @@ static char rcsid[] =
 extern void task_dump();
 char *debug_flags();
 char *inadport_hex();
+char *pvmnametag();
 void i_dump();
 void tev_send_newtask();
 void tev_send_spntask();
@@ -571,11 +592,11 @@ tm_connect(tp, mp)
 	(void)PVMTMPNAMFUN(tp->t_authnam);
 
 #ifndef IMA_OS2
-	if ((tp->t_authfd = open(tp->t_authnam, O_RDONLY|O_CREAT|O_TRUNC, 0600))
+	if ((tp->t_authfd = open(tp->t_authnam, O_RDONLY|O_CREAT|O_EXCL|O_TRUNC, 0600)) == -1)
 #else
-	if ((tp->t_authfd = open(tp->t_authnam, O_RDWR|O_CREAT|O_TRUNC, 0600))
+	if ((tp->t_authfd = open(tp->t_authnam, O_RDWR|O_CREAT|O_EXCL|O_TRUNC, 0600)) == -1)
 #endif
-	== -1) {
+	{
 		pvmlogperror("tm_connect() can't create d-auth file");
 		PVM_FREE(tp->t_authnam);
 		tp->t_authnam = 0;
@@ -600,7 +621,19 @@ tm_connect(tp, mp)
 	return 0;
 
 bail:
+
 	tp->t_flag |= TF_CLOSE;
+
+	/* better send a failure notification to the task... */
+	/* (is this a good idea, or better to let task hang, */
+	/* i.e. for security purposes - unresponsiveness...?) */
+	mp = replymessage(mp);
+	pkint(mp, TDPROTOCOL);
+	pkint(mp, 0);
+	pkstr(mp, "");
+	mp->m_flag |= MM_PRIO;
+	mesg_to_task(tp, mp);
+	pmsg_unref(mp);
 	return 0;
 }
 
@@ -697,7 +730,7 @@ tm_conn2(tp, mp)
 		tp->t_sched = tp2->t_sched;
 
 #ifdef IMA_BEOLIN
-	} else if ( (tp2 = mpp_find(tp))
+	} else if ( (tp2 = mpp_conn(tp))
 			&& !(tp2->t_flag & (TF_AUTH|TF_CONN)) ) {
 		if (pvmdebmask & PDMTASK) {
 			pvmlogprintf(
@@ -818,7 +851,15 @@ tm_conn2(tp, mp)
 	pkint(mp, tp->t_trctag);
 	pkint(mp, pvmudpmtu);
 	pkint(mp, pvmmydsig);
+#ifdef IMA_BEOLIN
+	if (TIDISNODE(tp->t_tid))
+		/* on a node, use the address that came from nodeaddr[] */
+		pkstr(mp, inadport_hex(&(tp->t_sad)));
+	else
+		pkstr(mp, inadport_hex(&(hosts->ht_hosts[hosts->ht_local]->hd_sad)));
+#else
 	pkstr(mp, inadport_hex(&(hosts->ht_hosts[hosts->ht_local]->hd_sad)));
+#endif
 	pkint(mp, pvmschedtid);
 	mp->m_dst = tp->t_tid;
 	mp->m_flag |= MM_PRIO;
@@ -2303,7 +2344,7 @@ tm_hoster(tp, mp)
 
 	mp2 = replymessage(mp);
 
-	/* always wear 2 condoms, who knows if indices are enough... :) */
+	/* always wear 2 condoms, who knows if indices are enough... :D */
 	if (hosts->ht_hosts[hosts->ht_local]->hd_hostpart
 			!= hosts->ht_hosts[hosts->ht_master]->hd_hostpart) {
 		pkint(mp2, PvmHostrNMstr);
