@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: tev.c,v 1.9 1998/11/20 20:04:18 pvmsrc Exp $";
+	"$Id: tev.c,v 1.10 2001/02/07 23:15:59 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -42,12 +42,10 @@ static char rcsid[] =
 #include <stdio.h>
 
 #include <pvm3.h>
-#ifdef WIN32
-#ifndef _XDR_HEADERS
-#define _XDR_HEADERS
+
+#if defined(WIN32) || defined(CYGWIN)
 #include "..\xdr\types.h"
 #include "..\xdr\xdr.h"
-#endif
 #else
 #include <rpc/types.h>
 #include <rpc/xdr.h>
