@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: trcsort.c,v 4.11 1997/12/01 20:21:20 pvmsrc Exp $";
+	"$Id: trcsort.c,v 4.14 2009/01/30 21:23:58 pvmsrc Exp $";
 
 /*
  *         Trcsort version 1.0:  A Trace File Sorter for PVM
@@ -30,7 +30,15 @@ static char rcsid[] =
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <fcntl.h>
+
+#ifdef HASSTDLIB
+#include <stdlib.h>
+#else
+#ifndef IMA_MACOSX
 #include <malloc.h>
+#endif
+#endif
 
 #ifdef  SYSVSTR
 #include <string.h>
@@ -596,6 +604,8 @@ program_init()
 void
 trc_init()
 {
+	int fd;
+
 	/* Initialize Tracer */
 
 	trc_tracer_init();
@@ -630,7 +640,11 @@ trc_init()
 
 	if ( TRACE_OUTFILE != NULL )
 	{
-		ID->trace_out = fopen( TRACE_OUTFILE, "w" );
+		fd = open( TRACE_OUTFILE, O_RDWR|O_CREAT|O_EXCL|O_TRUNC, 0600 );
+		if ( !trc_fdcheck( fd, TRACE_OUTFILE ) )
+			bail();
+
+		ID->trace_out = fdopen( fd, "w" );
 		if ( !trc_filecheck( ID->trace_out, TRACE_OUTFILE ) )
 			bail();
 	}
@@ -915,6 +929,8 @@ char *rwstr;
 	FPBUF FPBptr;
 	FPBUF FPB;
 
+	int fd;
+
 	/* File Ptr Buffer Already There */
 
 	if ( TF->fpbuf )
@@ -992,7 +1008,29 @@ char *rwstr;
 
 	FPB = create_fpbuf();
 
-	FPB->fp = fopen( TF->fname, rwstr );
+	if ( !strcmp( rwstr, "w" ) )
+	{
+		fd = open( TF->fname, O_RDWR|O_CREAT|O_EXCL|O_TRUNC, 0600 );
+
+		if ( !trc_fdcheck( fd, TF->fname ) )
+			return( TRC_FALSE );
+
+		FPB->fp = fdopen( fd, rwstr );
+	}
+
+	else if ( !strcmp( rwstr, "a" ) )
+	{
+		fd = open( TF->fname,
+				O_RDWR|O_APPEND|O_CREAT|O_EXCL|O_TRUNC, 0600 );
+
+		if ( !trc_fdcheck( fd, TF->fname ) )
+			return( TRC_FALSE );
+
+		FPB->fp = fdopen( fd, rwstr );
+	}
+
+	else
+		FPB->fp = fopen( TF->fname, rwstr );
 
 	if ( !trc_filecheck( FPB->fp, TF->fname ) )
 	{
