@@ -1,6 +1,6 @@
 
 static char rcsid[] = 
-	"$Id: trcutil.c,v 4.15 1999/03/22 15:25:58 pvmsrc Exp $";
+	"$Id: trcutil.c,v 4.16 2009/01/30 21:23:58 pvmsrc Exp $";
 
 /*
  *         Tracer version 1.0:  A Trace File Generator for PVM
@@ -27,6 +27,9 @@ static char rcsid[] =
 
 #include "trclib.h"
 
+#include <sys/stat.h>
+#include <fcntl.h>
+
 #ifdef WIN32
 #include <winsock.h>
 #endif
@@ -187,6 +190,7 @@ TRC_ID ID;
 {
 	TRC_TEVDESC TD;
 
+	int fd;
 	int i;
 
 	/* Close Any Existing Trace File */
@@ -215,7 +219,12 @@ TRC_ID ID;
 
 	if ( strcmp( ID->trace_file, "" ) )
 	{
-		ID->trace_out = fopen( ID->trace_file, "w" );
+		fd = open( ID->trace_file, O_RDWR|O_CREAT|O_EXCL|O_TRUNC, 0600 );
+
+		if ( !trc_fdcheck( fd, ID->trace_file ) )
+			return( TRC_FALSE );
+
+		ID->trace_out = fdopen( fd, "w" );
 
 		if ( !trc_filecheck( ID->trace_out, ID->trace_file ) )
 			return( TRC_FALSE );
@@ -296,6 +305,8 @@ int
 trc_open_output_file( ID )
 TRC_ID ID;
 {
+	int fd;
+
 	/* Close Any Existing Output File */
 
 	if ( ID->output_fp != NULL && ID->output_fp != stdout )
@@ -314,7 +325,12 @@ TRC_ID ID;
 
 	if ( strcmp( ID->output_file, "" ) )
 	{
-		ID->output_fp = fopen( ID->output_file, "w" );
+		fd = open( ID->output_file, O_RDWR|O_CREAT|O_EXCL|O_TRUNC, 0600 );
+
+		if ( !trc_fdcheck( fd, ID->output_file ) )
+			return( TRC_FALSE );
+
+		ID->output_fp = fdopen( fd, "w" );
 
 		if ( !trc_filecheck( ID->output_fp, ID->output_file ) )
 			return( TRC_FALSE );
@@ -3028,6 +3044,22 @@ char *str;
 }
 
 
+int
+trc_fdcheck( fd, name )
+int fd;
+char *name;
+{
+	if ( fd < 0 )
+	{
+		fprintf( stderr, "\nError Opening File \"%s\"\n\n", name );
+
+		return( TRC_FALSE );
+	}
+
+	return( TRC_TRUE );
+}
+
+
 int
 trc_filecheck( fp, name )
 FILE *fp;
