@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: mmain.c,v 1.2 1997/07/09 13:56:55 pvmsrc Exp $";
+	"$Id: mmain.c,v 1.3 2009/01/30 21:24:06 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -124,7 +124,7 @@ main(argc, argv)
 	pix = mandelbrot(x1, y1, x2, y2, wd, ht);
 
 	fputs("writing\n", stderr);
-	if ((d = open(dfn, O_WRONLY|O_CREAT|O_TRUNC, 0666)) == -1) {
+	if ((d = open(dfn, O_WRONLY|O_CREAT|O_EXCL|O_TRUNC, 0666)) == -1) {
 		perror(dfn);
 
 	} else {
